@@ -39,12 +39,11 @@ struct _GeglConfig
   guint64  tile_cache_size;
   gint     chunk_size; /* The size of elements being processed at once */
   gdouble  quality;
-  gdouble  babl_tolerance;
   gint     tile_width;
   gint     tile_height;
-  gint     threads;
   gboolean use_opencl;
-  gint     queue_limit;
+  gint     queue_size;
+  gchar   *application_license;
 };
 
 struct _GeglConfigClass
@@ -52,7 +51,10 @@ struct _GeglConfigClass
   GObjectClass parent_class;
 };
 
-GeglConfig   * gegl_config            (void);
+extern gint _gegl_threads;
+#define gegl_config_threads()  (_gegl_threads)
+
+#define GEGL_MAX_THREADS 16
 
 G_END_DECLS
 
