@@ -96,7 +96,7 @@ guint gegl_debug_flags = 0;
 #include "buffer/gegl-buffer.h"
 #include "operation/gegl-operation.h"
 #include "operation/gegl-operations.h"
-#include "operation/gegl-extension-handler-private.h"
+#include "operation/gegl-operation-handlers-private.h"
 #include "buffer/gegl-buffer-private.h"
 #include "buffer/gegl-buffer-iterator-private.h"
 #include "buffer/gegl-tile-backend-ram.h"
@@ -222,6 +222,13 @@ gegl_init_i18n (void)
     }
 }
 
+static GThread *main_thread = NULL;
+
+gboolean gegl_is_main_thread (void)
+{
+  return g_thread_self () == main_thread;
+}
+
 void
 gegl_init (gint    *argc,
            gchar ***argv)
@@ -233,6 +240,7 @@ gegl_init (gint    *argc,
   if (initialized)
     return;
 
+
   initialized = TRUE;
 
   context = g_option_context_new (NULL);
@@ -454,7 +462,7 @@ gegl_exit (void)
   gegl_tile_backend_swap_cleanup ();
   gegl_tile_cache_destroy ();
   gegl_operation_gtype_cleanup ();
-  gegl_extension_handler_cleanup ();
+  gegl_operation_handlers_cleanup ();
   gegl_random_cleanup ();
   gegl_cl_cleanup ();
 
@@ -702,6 +710,8 @@ gegl_post_parse_hook (GOptionContext *context,
                    NULL);
   gegl_operations_set_licenses_from_string (config->application_license);
 
+  main_thread = g_thread_self ();
+
   return TRUE;
 }
 
