@@ -25,6 +25,7 @@
 #include "gegl-operation-point-composer.h"
 #include "gegl-operation-context.h"
 #include "gegl-config.h"
+#include "gegl-types-internal.h"
 #include <sys/types.h>
 #include <unistd.h>
 #include <string.h>
@@ -102,13 +103,22 @@ gegl_operation_composer_process (GeglOperation        *operation,
                                  const GeglRectangle  *result,
                                  gint                  level)
 {
-  GeglOperationComposerClass *klass    = GEGL_OPERATION_COMPOSER_GET_CLASS (operation);
-  GeglOperationClass         *op_class = GEGL_OPERATION_CLASS (klass);
+  GeglOperationComposerClass *klass   = GEGL_OPERATION_COMPOSER_GET_CLASS (operation);
   GeglBuffer                 *input;
   GeglBuffer                 *aux;
   GeglBuffer                 *output;
   gboolean                    success = FALSE;
 
+  GeglRectangle scaled_result = *result;
+  if (level)
+  {
+    scaled_result.x >>= level;
+    scaled_result.y >>= level;
+    scaled_result.width >>= level;
+    scaled_result.height >>= level;
+    result = &scaled_result;
+  }
+
   if (strcmp (output_prop, "output"))
     {
       g_warning ("requested processing of %s pad on a composer", output_prop);
@@ -121,18 +131,11 @@ gegl_operation_composer_process (GeglOperation        *operation,
     return TRUE;
   }
 
-  input = gegl_operation_context_get_source (context, "input");
-
-  if (op_class->want_in_place && 
-      gegl_can_do_inplace_processing (operation, input, result))
-    {
-      output = g_object_ref (input);
-      gegl_operation_context_take_object (context, "output", G_OBJECT (output));
-    }
-  else
-    {
-      output = gegl_operation_context_get_target (context, "output");
-    }
+  input  = gegl_operation_context_get_source (context, "input");
+  output = gegl_operation_context_get_output_maybe_in_place (operation,
+                                                             context,
+                                                             input,
+                                                             result);
 
   aux   = gegl_operation_context_get_source (context, "aux");
 
@@ -170,7 +173,7 @@ G_DEFINE_TYPE (GeglOperationPointComposer, gegl_operation_point_composer, GEGL_T
 
 static void prepare (GeglOperation *operation)
 {
-  const Babl *format = babl_format ("RGBA float");
+  const Babl *format = gegl_babl_rgba_linear_float ();
   gegl_operation_set_format (operation, "input", format);
   gegl_operation_set_format (operation, "aux", format);
   gegl_operation_set_format (operation, "output", format);
