@@ -26,6 +26,7 @@
 #include "gegl-operation-point-filter.h"
 #include "gegl-operation-context.h"
 #include "gegl-config.h"
+#include "gegl-types-internal.h"
 #include <sys/types.h>
 #include <unistd.h>
 #include <string.h>
@@ -98,11 +99,20 @@ gegl_operation_filter_process (GeglOperation        *operation,
                                  gint                  level)
 {
   GeglOperationFilterClass *klass    = GEGL_OPERATION_FILTER_GET_CLASS (operation);
-  GeglOperationClass         *op_class = GEGL_OPERATION_CLASS (klass);
   GeglBuffer                 *input;
   GeglBuffer                 *output;
   gboolean                    success = FALSE;
 
+  GeglRectangle scaled_result = *result;
+  if (level)
+  {
+    scaled_result.x >>= level;
+    scaled_result.y >>= level;
+    scaled_result.width >>= level;
+    scaled_result.height >>= level;
+    result = &scaled_result;
+  }
+
   if (strcmp (output_prop, "output"))
     {
       g_warning ("requested processing of %s pad on a filter", output_prop);
@@ -115,25 +125,16 @@ gegl_operation_filter_process (GeglOperation        *operation,
     return TRUE;
   }
 
-  input = gegl_operation_context_get_source (context, "input");
-
-  if (op_class->want_in_place && 
-      gegl_can_do_inplace_processing (operation, input, result))
-    {
-      output = g_object_ref (input);
-      gegl_operation_context_take_object (context, "output", G_OBJECT (output));
-    }
-  else
-    {
-      output = gegl_operation_context_get_target (context, "output");
-    }
+  input  = gegl_operation_context_get_source (context, "input");
+  output = gegl_operation_context_get_output_maybe_in_place (operation,
+                                                             context,
+                                                             input,
+                                                             result);
 
   if (input != NULL)
     {
       success = klass->process (operation, input, output, result, level);
-
-      if (input)
-        g_object_unref (input);
+      g_clear_object (&input);
     }
   else
     {
@@ -155,7 +156,7 @@ G_DEFINE_TYPE (GeglOperationPointFilter, gegl_operation_point_filter, GEGL_TYPE_
 
 static void prepare (GeglOperation *operation)
 {
-  const Babl *format = babl_format ("RGBA float");
+  const Babl *format = gegl_babl_rgba_linear_float ();
   gegl_operation_set_format (operation, "input", format);
   gegl_operation_set_format (operation, "output", format);
 }
