@@ -24,6 +24,7 @@
 #include "gegl.h"
 #include "gegl-operation-point-render.h"
 #include "gegl-operation-context.h"
+#include "gegl-types-internal.h"
 
 static gboolean gegl_operation_point_render_process
                               (GeglOperation       *operation,
@@ -35,7 +36,8 @@ G_DEFINE_TYPE (GeglOperationPointRender, gegl_operation_point_render, GEGL_TYPE_
 
 static void prepare (GeglOperation *operation)
 {
-  gegl_operation_set_format (operation, "output", babl_format ("RGBA float"));
+  const Babl *format = gegl_babl_rgba_linear_float ();
+  gegl_operation_set_format (operation, "output", format);
 }
 
 static GeglNode *
@@ -78,6 +80,16 @@ gegl_operation_point_render_process (GeglOperation       *operation,
   const Babl *out_format;
   GeglOperationPointRenderClass *point_render_class;
 
+  GeglRectangle scaled_result = *result;
+  if (level)
+  {
+    scaled_result.x >>= level;
+    scaled_result.y >>= level;
+    scaled_result.width >>= level;
+    scaled_result.height >>= level;
+    result = &scaled_result;
+  }
+
   point_render_class = GEGL_OPERATION_POINT_RENDER_GET_CLASS (operation);
 
   out_format = gegl_operation_get_format (operation, "output");
