@@ -279,7 +279,9 @@ static const char* op_c_source =
 "    \"title\",       _(\"Scale3X Antialiasing\"),                             \n"
 "    \"categories\",  \"enhance\",                                             \n"
 "    \"license\",     \"GPL3+\",                                               \n"
+"    \"reference-hash\", \"265d02a3b3cd11bd7b612feca3706fec\",                 \n"
 "    \"description\", _(\"Antialias using the Scale3X edge-extrapolation algorithm\"),\n"
+"    \"reference-chain\",    \"load path=images/standard-input.png threshold antialias\",\n"
 "    NULL);                                                                    \n"
 "}                                                                             \n"
 "                                                                              \n"
