@@ -96,6 +96,11 @@ static const char* op_c_source =
 "  Priv           *p         = get_priv (o);                                   \n"
 "  GeglBuffer     *buffer    = NULL;                                           \n"
 "                                                                              \n"
+"  /* we split buffer replacement into two parts -- before and after calling   \n"
+"   * set_property() to update o->buffer -- so that code executed as a result  \n"
+"   * of the invalidation performed by buffer_changed() sees the op with the   \n"
+"   * right buffer.                                                            \n"
+"   */                                                                         \n"
 "  switch (property_id)                                                        \n"
 "    {                                                                         \n"
 "    case PROP_buffer:                                                         \n"
@@ -110,7 +115,20 @@ static const char* op_c_source =
 "                          gegl_buffer_get_extent (GEGL_BUFFER (o->buffer)),   \n"
 "                          operation);                                         \n"
 "        }                                                                     \n"
+"      break;                                                                  \n"
 "                                                                              \n"
+"    default:                                                                  \n"
+"      break;                                                                  \n"
+"  }                                                                           \n"
+"                                                                              \n"
+"  /* The set_property provided by the chant system does the storing           \n"
+"   * and reffing/unreffing of the input properties                            \n"
+"   */                                                                         \n"
+"  set_property (object, property_id, value, pspec);                           \n"
+"                                                                              \n"
+"  switch (property_id)                                                        \n"
+"    {                                                                         \n"
+"    case PROP_buffer:                                                         \n"
 "      buffer = g_value_get_object (value);                                    \n"
 "                                                                              \n"
 "      if (buffer)                                                             \n"
@@ -128,11 +146,6 @@ static const char* op_c_source =
 "    default:                                                                  \n"
 "      break;                                                                  \n"
 "  }                                                                           \n"
-"                                                                              \n"
-"  /* The set_property provided by the chant system does the storing           \n"
-"   * and reffing/unreffing of the input properties                            \n"
-"   */                                                                         \n"
-"  set_property (object, property_id, value, pspec);                           \n"
 "}                                                                             \n"
 "                                                                              \n"
 "static gboolean                                                               \n"
