@@ -345,8 +345,9 @@ static const char* op_c_source =
 "    \"name\",               \"gegl:checkerboard\",                            \n"
 "    \"categories\",         \"render\",                                       \n"
 "    \"title\",              _(\"Checkerboard\"),                              \n"
+"    \"reference-hash\",     \"b2f5f85a0ec1de87639c1b0cfcd17fbc\",             \n"
 "    \"position-dependent\", \"true\",                                         \n"
-"    \"description\",        _(\"Create a checkerboard pattern\"),             \n"
+"    \"description\",        _(\"Render a checkerboard pattern\"),             \n"
 "    NULL);                                                                    \n"
 "}                                                                             \n"
 "                                                                              \n"
