@@ -36,13 +36,19 @@ static const char* op_c_source =
 "#include \"gegl-op.h\"                                                        \n"
 "                                                                              \n"
 "static void                                                                   \n"
-"buffer_get_min_max (GeglBuffer *buffer,                                       \n"
-"                    gdouble    *min,                                          \n"
-"                    gdouble    *max)                                          \n"
+"buffer_get_min_max (GeglOperation       *operation,                           \n"
+"                    GeglBuffer          *buffer,                              \n"
+"                    const GeglRectangle *result,                              \n"
+"                    gdouble             *min,                                 \n"
+"                    gdouble             *max)                                 \n"
 "{                                                                             \n"
 "  GeglBufferIterator *gi;                                                     \n"
+"  gint                done_pixels = 0;                                        \n"
 "                                                                              \n"
-"  gi = gegl_buffer_iterator_new (buffer, NULL, 0, babl_format (\"CIE LCH(ab) float\"),\n"
+"  gegl_operation_progress (operation, 0.0, \"\");                             \n"
+"                                                                              \n"
+"  gi = gegl_buffer_iterator_new (buffer, result, 0,                           \n"
+"                                 babl_format (\"CIE LCH(ab) float\"),         \n"
 "                                 GEGL_ACCESS_READ, GEGL_ABYSS_NONE);          \n"
 "                                                                              \n"
 "  *min = G_MAXDOUBLE;                                                         \n"
@@ -59,7 +65,16 @@ static const char* op_c_source =
 "          *max = MAX (buf[1], *max);                                          \n"
 "          buf += 3;                                                           \n"
 "        }                                                                     \n"
+"                                                                              \n"
+"      done_pixels += gi->length;                                              \n"
+"                                                                              \n"
+"      gegl_operation_progress (operation,                                     \n"
+"                               (gdouble) 0.5 * done_pixels /                  \n"
+"                               (gdouble) (result->width * result->height),    \n"
+"                               \"\");                                         \n"
 "    }                                                                         \n"
+"                                                                              \n"
+"  gegl_operation_progress (operation, 0.5, \"\");                             \n"
 "}                                                                             \n"
 "                                                                              \n"
 "static void prepare (GeglOperation *operation)                                \n"
@@ -120,11 +135,14 @@ static const char* op_c_source =
 "  const Babl *format = gegl_operation_get_format (operation, \"output\");     \n"
 "  gboolean has_alpha = babl_format_has_alpha (format);                        \n"
 "  GeglBufferIterator *gi;                                                     \n"
+"  gint                done_pixels = 0;                                        \n"
 "  gdouble  min;                                                               \n"
 "  gdouble  max;                                                               \n"
 "  gdouble  delta;                                                             \n"
 "                                                                              \n"
-"  buffer_get_min_max (input, &min, &max);                                     \n"
+"  buffer_get_min_max (operation, input, result, &min, &max);                  \n"
+"                                                                              \n"
+"  gegl_operation_progress (operation, 0.5, \"\");                             \n"
 "                                                                              \n"
 "  gi = gegl_buffer_iterator_new (input, result, 0, format,                    \n"
 "                                 GEGL_ACCESS_READ, GEGL_ABYSS_NONE);          \n"
@@ -159,7 +177,15 @@ static const char* op_c_source =
 "              in  += 4;                                                       \n"
 "              out += 4;                                                       \n"
 "            }                                                                 \n"
-"        }                                                                     \n"
+"                                                                              \n"
+"          done_pixels += gi->length;                                          \n"
+"                                                                              \n"
+"          gegl_operation_progress (operation,                                 \n"
+"                                   0.5 +                                      \n"
+"                                   (gdouble) 0.5 * done_pixels /              \n"
+"                                   (gdouble) (result->width * result->height),\n"
+"                                   \"\");                                     \n"
+"       }                                                                      \n"
 "    }                                                                         \n"
 "  else                                                                        \n"
 "    {                                                                         \n"
@@ -178,9 +204,19 @@ static const char* op_c_source =
 "              in  += 3;                                                       \n"
 "              out += 3;                                                       \n"
 "            }                                                                 \n"
+"                                                                              \n"
+"          done_pixels += gi->length;                                          \n"
+"                                                                              \n"
+"          gegl_operation_progress (operation,                                 \n"
+"                                   0.5 +                                      \n"
+"                                   (gdouble) 0.5 * done_pixels /              \n"
+"                                   (gdouble) (result->width * result->height),\n"
+"                                   \"\");                                     \n"
 "        }                                                                     \n"
 "    }                                                                         \n"
 "                                                                              \n"
+"  gegl_operation_progress (operation, 1.0, \"\");                             \n"
+"                                                                              \n"
 "  return TRUE;                                                                \n"
 "}                                                                             \n"
 "                                                                              \n"
@@ -236,6 +272,7 @@ static const char* op_c_source =
 "    \"name\",        \"gegl:color-enhance\",                                  \n"
 "    \"title\",       _(\"Color Enhance\"),                                    \n"
 "    \"categories\" , \"color:enhance\",                                       \n"
+"    \"reference-hash\", \"f8f470769afc06b08bcef46c2f44c406\",                 \n"
 "    \"description\",                                                          \n"
 "        _(\"Stretch color chroma to cover maximum possible range, \"          \n"
 "          \"keeping hue and lightness untouched.\"),                          \n"
