@@ -51,9 +51,11 @@ static const char* op_c_source =
 "                                                                              \n"
 "property_double (divisor, _(\"Divisor\"), 1.0)                                \n"
 "    ui_range    (-1000.0, 1000.0)                                             \n"
+"    ui_meta     (\"sensitive\", \"! normalize\")                              \n"
 "                                                                              \n"
 "property_double (offset, _(\"Offset\"), 0.0)                                  \n"
 "    value_range (-1.0, 1.0)                                                   \n"
+"    ui_meta     (\"sensitive\", \"! normalize\")                              \n"
 "                                                                              \n"
 "property_boolean (red,   _(\"Red channel\"),   TRUE)                          \n"
 "property_boolean (green, _(\"Green channel\"), TRUE)                          \n"
@@ -613,6 +615,7 @@ static const char* op_c_source =
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "    \"categories\",  \"generic\",                                             \n"
 "    \"name\",        \"gegl:convolution-matrix\",                             \n"
+"    \"title\",       _(\"Convolution Matrix\"),                               \n"
 "    \"description\", _(\"Apply a generic 5x5 convolution matrix\"),           \n"
 "    NULL);                                                                    \n"
 "}                                                                             \n"
