@@ -80,6 +80,19 @@ static const char* op_c_source =
 "                             babl_format (\"RGBA float\"));                   \n"
 "}                                                                             \n"
 "                                                                              \n"
+"static GeglRectangle                                                          \n"
+"get_bounding_box (GeglOperation *operation)                                   \n"
+"{                                                                             \n"
+"  GeglRectangle  result = { 0, 0, 0, 0 };                                     \n"
+"  GeglRectangle *in_rect;                                                     \n"
+"                                                                              \n"
+"  in_rect = gegl_operation_source_get_bounding_box (operation, \"input\");    \n"
+"  if (!in_rect)                                                               \n"
+"    return result;                                                            \n"
+"                                                                              \n"
+"  return *in_rect;                                                            \n"
+"}                                                                             \n"
+"                                                                              \n"
 "static void                                                                   \n"
 "deinterlace_horizontal (gfloat              *src_buf,                         \n"
 "                        gfloat              *dest,                            \n"
@@ -218,18 +231,6 @@ static const char* op_c_source =
 "    }                                                                         \n"
 "}                                                                             \n"
 "                                                                              \n"
-"static GeglRectangle                                                          \n"
-"get_effective_area (GeglOperation *operation)                                 \n"
-"{                                                                             \n"
-"  GeglRectangle  result  = { 0, 0, 0, 0 };                                    \n"
-"  GeglRectangle *in_rect = gegl_operation_source_get_bounding_box (operation, \n"
-"                                                                   \"input\");\n"
-"                                                                              \n"
-"  gegl_rectangle_copy (&result, in_rect);                                     \n"
-"                                                                              \n"
-"  return result;                                                              \n"
-"}                                                                             \n"
-"                                                                              \n"
 "static gboolean                                                               \n"
 "process (GeglOperation       *operation,                                      \n"
 "         GeglBuffer          *input,                                          \n"
@@ -241,7 +242,7 @@ static const char* op_c_source =
 "  GeglOperationAreaFilter *op_area  = GEGL_OPERATION_AREA_FILTER (operation); \n"
 "  const Babl              *format   = babl_format (\"RGBA float\");           \n"
 "  GeglRectangle            rect;                                              \n"
-"  GeglRectangle            boundary = get_effective_area (operation);         \n"
+"  GeglRectangle            boundary = get_bounding_box (operation);           \n"
 "  gint                     x, y;                                              \n"
 "  gfloat                  *dst_buf, *src_buf;                                 \n"
 "                                                                              \n"
@@ -293,27 +294,6 @@ static const char* op_c_source =
 "  return  TRUE;                                                               \n"
 "}                                                                             \n"
 "                                                                              \n"
-"static GeglRectangle                                                          \n"
-"get_bounding_box (GeglOperation *operation)                                   \n"
-"{                                                                             \n"
-"  GeglRectangle  result = { 0, 0, 0, 0 };                                     \n"
-"  GeglRectangle *in_rect;                                                     \n"
-"                                                                              \n"
-"  in_rect = gegl_operation_source_get_bounding_box (operation, \"input\");    \n"
-"  if (!in_rect)                                                               \n"
-"    return result;                                                            \n"
-"                                                                              \n"
-"  return *in_rect;                                                            \n"
-"}                                                                             \n"
-"                                                                              \n"
-"static GeglRectangle                                                          \n"
-"get_required_for_output (GeglOperation       *operation,                      \n"
-"                         const gchar         *input_pad,                      \n"
-"                         const GeglRectangle *roi)                            \n"
-"{                                                                             \n"
-"  return get_bounding_box (operation);                                        \n"
-"}                                                                             \n"
-"                                                                              \n"
 "static void                                                                   \n"
 "gegl_op_class_init (GeglOpClass *klass)                                       \n"
 "{                                                                             \n"
@@ -323,10 +303,9 @@ static const char* op_c_source =
 "  operation_class = GEGL_OPERATION_CLASS (klass);                             \n"
 "  filter_class    = GEGL_OPERATION_FILTER_CLASS (klass);                      \n"
 "                                                                              \n"
-"  operation_class->prepare                 = prepare;                         \n"
-"  operation_class->get_bounding_box        = get_bounding_box;                \n"
-"  operation_class->get_required_for_output = get_required_for_output;         \n"
-"  filter_class->process                    = process;                         \n"
+"  operation_class->prepare           = prepare;                               \n"
+"  operation_class->get_bounding_box  = get_bounding_box;                      \n"
+"  filter_class->process              = process;                               \n"
 "                                                                              \n"
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "    \"name\",               \"gegl:deinterlace\",                             \n"
@@ -334,6 +313,7 @@ static const char* op_c_source =
 "    \"categories\",         \"enhance\",                                      \n"
 "    \"license\",            \"GPL3+\",                                        \n"
 "    \"position-dependent\", \"true\",                                         \n"
+"    \"reference-hash\",     \"663e775f191a41aaf1039b883615d786\",             \n"
 "    \"description\", _(\"Fix images where every other row or column is missing\"),\n"
 "    NULL);                                                                    \n"
 "}                                                                             \n"
