@@ -99,6 +99,12 @@ static const char* op_c_source =
 "#define GEGL_OP_C_SOURCE diffraction-patterns.c                               \n"
 "                                                                              \n"
 "#include \"gegl-op.h\"                                                        \n"
+"#include <gegl-buffer-cl-iterator.h>                                          \n"
+"#include <gegl-debug.h>                                                       \n"
+"                                                                              \n"
+"#include \"opencl/diffraction-patterns.cl.h\"                                 \n"
+"                                                                              \n"
+"static GeglClRunData *cl_data = NULL;                                         \n"
 "                                                                              \n"
 "#define ITERATIONS      100                                                   \n"
 "#define WEIRD_FACTOR    0.04                                                  \n"
@@ -194,11 +200,90 @@ static const char* op_c_source =
 "}                                                                             \n"
 "                                                                              \n"
 "static gboolean                                                               \n"
-"process (GeglOperation       *operation,                                      \n"
-"         void                *out_buf,                                        \n"
-"         glong                n_pixels,                                       \n"
-"         const GeglRectangle *roi,                                            \n"
-"         gint                 level)                                          \n"
+"cl_process (GeglOperation       *operation,                                   \n"
+"            cl_mem               out_tex,                                     \n"
+"            const GeglRectangle *roi)                                         \n"
+"{                                                                             \n"
+"  GeglProperties   *o      = GEGL_PROPERTIES (operation);                     \n"
+"  const size_t  gbl_size[] = { roi->width, roi->height };                     \n"
+"  cl_int        cl_err     = 0;                                               \n"
+"  cl_int offset_x;                                                            \n"
+"  cl_int offset_y;                                                            \n"
+"  cl_int width;                                                               \n"
+"  cl_int height;                                                              \n"
+"  cl_float3 sedges;                                                           \n"
+"  cl_float3 contours;                                                         \n"
+"  cl_float3 frequency;                                                        \n"
+"  cl_float brightness;                                                        \n"
+"  cl_float polarization;                                                      \n"
+"  cl_float scattering;                                                        \n"
+"  cl_int iterations;                                                          \n"
+"  cl_float weird_factor;                                                      \n"
+"                                                                              \n"
+"  if (!cl_data)                                                               \n"
+"    {                                                                         \n"
+"      const char *kernel_name[] = { \"cl_diffraction_patterns\", NULL };      \n"
+"      cl_data = gegl_cl_compile_and_build (diffraction_patterns_cl_source,    \n"
+"                                           kernel_name);                      \n"
+"                                                                              \n"
+"      if (!cl_data)                                                           \n"
+"        return TRUE;                                                          \n"
+"    }                                                                         \n"
+"                                                                              \n"
+"  offset_x = roi->x;                                                          \n"
+"  offset_y = roi->y;                                                          \n"
+"  width = o->width;                                                           \n"
+"  height = o->height;                                                         \n"
+"  sedges.s[0] = o->red_sedges;                                                \n"
+"  sedges.s[1] = o->green_sedges;                                              \n"
+"  sedges.s[2] = o->blue_sedges;                                               \n"
+"  contours.s[0] = o->red_contours;                                            \n"
+"  contours.s[1] = o->green_contours;                                          \n"
+"  contours.s[2] = o->blue_contours;                                           \n"
+"  frequency.s[0] = o->red_frequency;                                          \n"
+"  frequency.s[1] = o->green_frequency;                                        \n"
+"  frequency.s[2] = o->blue_frequency;                                         \n"
+"  brightness = o->brightness;                                                 \n"
+"  polarization = o->polarization;                                             \n"
+"  scattering = o->scattering;                                                 \n"
+"  iterations = ITERATIONS;                                                    \n"
+"  weird_factor = WEIRD_FACTOR;                                                \n"
+"  cl_err = gegl_cl_set_kernel_args (cl_data->kernel[0],                       \n"
+"                                    sizeof(cl_mem),    &out_tex,              \n"
+"                                    sizeof(cl_int),    &offset_x,             \n"
+"                                    sizeof(cl_int),    &offset_y,             \n"
+"                                    sizeof(cl_int),    &width,                \n"
+"                                    sizeof(cl_int),    &height,               \n"
+"                                    sizeof(cl_float3), &sedges,               \n"
+"                                    sizeof(cl_float3), &contours,             \n"
+"                                    sizeof(cl_float3), &frequency,            \n"
+"                                    sizeof(cl_float),  &brightness,           \n"
+"                                    sizeof(cl_float),  &polarization,         \n"
+"                                    sizeof(cl_float),  &scattering,           \n"
+"                                    sizeof(cl_int),    &iterations,           \n"
+"                                    sizeof(cl_float),  &weird_factor,         \n"
+"                                    NULL);                                    \n"
+"  CL_CHECK;                                                                   \n"
+"                                                                              \n"
+"  cl_err = gegl_clEnqueueNDRangeKernel (gegl_cl_get_command_queue (),         \n"
+"                                        cl_data->kernel[0], 2,                \n"
+"                                        NULL, gbl_size, NULL,                 \n"
+"                                        0, NULL, NULL);                       \n"
+"  CL_CHECK;                                                                   \n"
+"                                                                              \n"
+"  cl_err = gegl_clFinish (gegl_cl_get_command_queue ());                      \n"
+"  CL_CHECK;                                                                   \n"
+"                                                                              \n"
+"  return FALSE;                                                               \n"
+"                                                                              \n"
+"error:                                                                        \n"
+"  return TRUE;                                                                \n"
+"}                                                                             \n"
+"                                                                              \n"
+"static gboolean                                                               \n"
+"c_process (GeglOperation       *operation,                                    \n"
+"           void                *out_buf,                                      \n"
+"           const GeglRectangle *roi)                                          \n"
 "{                                                                             \n"
 "  GeglProperties *o = GEGL_PROPERTIES (operation);                            \n"
 "  gfloat         *out;                                                        \n"
@@ -231,22 +316,69 @@ static const char* op_c_source =
 "  return TRUE;                                                                \n"
 "}                                                                             \n"
 "                                                                              \n"
+"static gboolean                                                               \n"
+"process (GeglOperation       *operation,                                      \n"
+"         GeglBuffer          *out_buf,                                        \n"
+"         const GeglRectangle *roi,                                            \n"
+"         gint                 level)                                          \n"
+"{                                                                             \n"
+"  GeglBufferIterator *iter;                                                   \n"
+"  const Babl         *out_format = gegl_operation_get_format (operation,      \n"
+"                                                              \"output\");    \n"
+"                                                                              \n"
+"  if (gegl_operation_use_opencl (operation))                                  \n"
+"    {                                                                         \n"
+"      GeglBufferClIterator *cl_iter;                                          \n"
+"      gboolean              err;                                              \n"
+"                                                                              \n"
+"      GEGL_NOTE (GEGL_DEBUG_OPENCL, \"GEGL_OPERATION_POINT_RENDER: %s\",      \n"
+"                 GEGL_OPERATION_GET_CLASS (operation)->name);                 \n"
+"                                                                              \n"
+"      cl_iter = gegl_buffer_cl_iterator_new (out_buf, roi, out_format,        \n"
+"                                             GEGL_CL_BUFFER_WRITE);           \n"
+"                                                                              \n"
+"      while (gegl_buffer_cl_iterator_next (cl_iter, &err) && !err)            \n"
+"        {                                                                     \n"
+"          err = cl_process (operation, cl_iter->tex[0], cl_iter->roi);        \n"
+"                                                                              \n"
+"          if (err)                                                            \n"
+"            {                                                                 \n"
+"              gegl_buffer_cl_iterator_stop (cl_iter);                         \n"
+"              break;                                                          \n"
+"            }                                                                 \n"
+"        }                                                                     \n"
+"                                                                              \n"
+"      if (err)                                                                \n"
+"        GEGL_NOTE (GEGL_DEBUG_OPENCL, \"Error: %s\",                          \n"
+"                   GEGL_OPERATION_GET_CLASS (operation)->name);               \n"
+"      else                                                                    \n"
+"        return TRUE;                                                          \n"
+"    }                                                                         \n"
+"                                                                              \n"
+"  iter = gegl_buffer_iterator_new (out_buf, roi, level, out_format,           \n"
+"                                   GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE);       \n"
+"                                                                              \n"
+"  while (gegl_buffer_iterator_next (iter))                                    \n"
+"    c_process (operation, iter->data[0], &iter->roi[0]);                      \n"
+"                                                                              \n"
+"  return  TRUE;                                                               \n"
+"}                                                                             \n"
+"                                                                              \n"
 "static void                                                                   \n"
 "gegl_op_class_init (GeglOpClass *klass)                                       \n"
 "{                                                                             \n"
-"  GeglOperationClass            *operation_class;                             \n"
-"  GeglOperationPointRenderClass *point_render_class;                          \n"
+"  GeglOperationClass       *operation_class;                                  \n"
+"  GeglOperationSourceClass *source_class;                                     \n"
 "                                                                              \n"
 "  init_luts();                                                                \n"
 "                                                                              \n"
-"  operation_class    = GEGL_OPERATION_CLASS (klass);                          \n"
-"  point_render_class = GEGL_OPERATION_POINT_RENDER_CLASS (klass);             \n"
-"                                                                              \n"
-"  point_render_class->process = process;                                      \n"
+"  operation_class = GEGL_OPERATION_CLASS (klass);                             \n"
+"  source_class    = GEGL_OPERATION_SOURCE_CLASS (klass);                      \n"
 "                                                                              \n"
+"  source_class->process = process;                                            \n"
 "  operation_class->get_bounding_box = get_bounding_box;                       \n"
 "  operation_class->prepare = prepare;                                         \n"
-"  operation_class->opencl_support = FALSE;                                    \n"
+"  operation_class->opencl_support = TRUE;                                     \n"
 "                                                                              \n"
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "    \"name\",               \"gegl:diffraction-patterns\",                    \n"
