@@ -51,6 +51,14 @@ static const char* op_c_source =
 "    ui_range    (-500.0, 500.0)                                               \n"
 "    ui_meta     (\"unit\", \"pixel-distance\")                                \n"
 "    ui_meta     (\"axis\", \"x\")                                             \n"
+"    ui_meta     (\"label\", \"[displace-mode {cartesian} : cartesian-label,\" \n"
+"                          \" displace-mode {polar}     : polar-label]\")      \n"
+"    ui_meta     (\"cartesian-label\", _(\"Horizontal displacement\"))         \n"
+"    ui_meta     (\"polar-label\", _(\"Pinch\"))                               \n"
+"    ui_meta     (\"description\", \"[displace-mode {cartesian} : cartesian-description,\"\n"
+"                                \" displace-mode {polar}     : polar-description]\")\n"
+"    ui_meta     (\"cartesian-description\", _(\"Displacement multiplier for the horizontal direction\"))\n"
+"    ui_meta     (\"polar-description\", _(\"Displacement multiplier for the radial direction\"))\n"
 "                                                                              \n"
 "property_double (amount_y, _(\"Y displacement\"), 0.0)                        \n"
 "    description (_(\"Displace multiplier for Y or tangent (degrees) direction\"))\n"
@@ -58,6 +66,31 @@ static const char* op_c_source =
 "    ui_range    (-500.0, 500.0)                                               \n"
 "    ui_meta     (\"unit\", \"pixel-distance\")                                \n"
 "    ui_meta     (\"axis\", \"y\")                                             \n"
+"    ui_meta     (\"label\", \"[displace-mode {cartesian} : cartesian-label,\" \n"
+"                          \" displace-mode {polar}     : polar-label]\")      \n"
+"    ui_meta     (\"cartesian-label\", _(\"Vertical displacement\"))           \n"
+"    ui_meta     (\"polar-label\", _(\"Whirl\"))                               \n"
+"    ui_meta     (\"description\", \"[displace-mode {cartesian} : cartesian-description,\"\n"
+"                                \" displace-mode {polar}     : polar-description]\")\n"
+"    ui_meta     (\"cartesian-description\", _(\"Displacement multiplier for the vertical direction\"))\n"
+"    ui_meta     (\"polar-description\", _(\"Displacement multiplier for the angular offset\"))\n"
+"                                                                              \n"
+"property_boolean (center, _(\"Center displacement\"), FALSE)                  \n"
+"    description (_(\"Center the displacement around a specified point\"))     \n"
+"                                                                              \n"
+"property_double (center_x, _(\"Center X\"), 0.5)                              \n"
+"    description (_(\"X coordinate of the displacement center\"))              \n"
+"    ui_range    (0.0, 1.0)                                                    \n"
+"    ui_meta     (\"unit\", \"relative-coordinate\")                           \n"
+"    ui_meta     (\"axis\", \"x\")                                             \n"
+"    ui_meta     (\"sensitive\", \"center\")                                   \n"
+"                                                                              \n"
+"property_double (center_y, _(\"Center Y\"), 0.5)                              \n"
+"    description (_(\"Y coordinate of the displacement center\"))              \n"
+"    ui_range    (0.0, 1.0)                                                    \n"
+"    ui_meta     (\"unit\", \"relative-coordinate\")                           \n"
+"    ui_meta     (\"axis\", \"y\")                                             \n"
+"    ui_meta     (\"sensitive\", \"center\")                                   \n"
 "                                                                              \n"
 "#else                                                                         \n"
 "                                                                              \n"
@@ -72,7 +105,7 @@ static const char* op_c_source =
 "get_base_displacement (gdouble  amount,                                       \n"
 "                       gfloat  *map_pixel)                                    \n"
 "{                                                                             \n"
-"  return (2.0 * amount * (map_pixel[0] - 0.5) - 0.5) * map_pixel[1] + 0.5;    \n"
+"  return 2.0 * amount * (map_pixel[0] - 0.5) * map_pixel[1];                  \n"
 "}                                                                             \n"
 "                                                                              \n"
 "static inline void                                                            \n"
@@ -123,7 +156,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "  if (ymap_pixel && y_amount)                                                 \n"
 "    {                                                                         \n"
-"      d_alpha += (y_amount / 180) * M_PI * (ymap_pixel[0] - 0.5) / 0.5;       \n"
+"      d_alpha += get_base_displacement ((y_amount / 180) * G_PI, ymap_pixel); \n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  *x_input = cx + radius * sin (d_alpha);                                     \n"
@@ -190,13 +223,34 @@ static const char* op_c_source =
 "                         const gchar         *input_pad,                      \n"
 "                         const GeglRectangle *roi)                            \n"
 "{                                                                             \n"
-"  GeglRectangle *result = gegl_operation_source_get_bounding_box (operation, \"input\");\n"
+"  GeglProperties *o      = GEGL_PROPERTIES (operation);                       \n"
+"  GeglRectangle  *result = gegl_operation_source_get_bounding_box (operation, \"input\");\n"
 "                                                                              \n"
 "  if (!strcmp (input_pad, \"aux\")  ||                                        \n"
 "      !strcmp (input_pad, \"aux2\") ||                                        \n"
 "      !result)                                                                \n"
 "    {                                                                         \n"
-"      return *roi;                                                            \n"
+"      GeglRectangle rect = *roi;                                              \n"
+"                                                                              \n"
+"      if (o->center && result)                                                \n"
+"        {                                                                     \n"
+"          GeglRectangle *bounds = gegl_operation_source_get_bounding_box (operation, input_pad);\n"
+"                                                                              \n"
+"          if (bounds)                                                         \n"
+"            {                                                                 \n"
+"              gdouble cx, cy;                                                 \n"
+"                                                                              \n"
+"              cx = result->x + gegl_coordinate_relative_to_pixel (o->center_x,\n"
+"                                                                  result->width);\n"
+"              cy = result->y + gegl_coordinate_relative_to_pixel (o->center_y,\n"
+"                                                                  result->height);\n"
+"                                                                              \n"
+"              rect.x += bounds->x + bounds->width  / 2 - floor (cx);          \n"
+"              rect.y += bounds->y + bounds->height / 2 - floor (cy);          \n"
+"            }                                                                 \n"
+"        }                                                                     \n"
+"                                                                              \n"
+"      return rect;                                                            \n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  return *result;                                                             \n"
@@ -207,13 +261,34 @@ static const char* op_c_source =
 "                           const gchar         *input_pad,                    \n"
 "                           const GeglRectangle *input_region)                 \n"
 "{                                                                             \n"
-"  GeglRectangle *result = gegl_operation_source_get_bounding_box (operation, \"input\");\n"
+"  GeglProperties *o      = GEGL_PROPERTIES (operation);                       \n"
+"  GeglRectangle  *result = gegl_operation_source_get_bounding_box (operation, \"input\");\n"
 "                                                                              \n"
 "  if (!strcmp (input_pad, \"aux\")  ||                                        \n"
 "      !strcmp (input_pad, \"aux2\") ||                                        \n"
 "      !result)                                                                \n"
 "    {                                                                         \n"
-"      return *input_region;                                                   \n"
+"      GeglRectangle rect = *input_region;                                     \n"
+"                                                                              \n"
+"      if (o->center && result)                                                \n"
+"        {                                                                     \n"
+"          GeglRectangle *bounds = gegl_operation_source_get_bounding_box (operation, input_pad);\n"
+"                                                                              \n"
+"          if (bounds)                                                         \n"
+"            {                                                                 \n"
+"              gdouble cx, cy;                                                 \n"
+"                                                                              \n"
+"              cx = result->x + gegl_coordinate_relative_to_pixel (o->center_x,\n"
+"                                                                  result->width);\n"
+"              cy = result->y + gegl_coordinate_relative_to_pixel (o->center_y,\n"
+"                                                                  result->height);\n"
+"                                                                              \n"
+"              rect.x -= bounds->x + bounds->width  / 2 - floor (cx);          \n"
+"              rect.y -= bounds->y + bounds->height / 2 - floor (cy);          \n"
+"            }                                                                 \n"
+"        }                                                                     \n"
+"                                                                              \n"
+"      return rect;                                                            \n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  return *result;                                                             \n"
@@ -233,7 +308,7 @@ static const char* op_c_source =
 "  GeglSampler        *in_sampler;                                             \n"
 "                                                                              \n"
 "  gint     x, y;                                                              \n"
-"  gdouble  cx = 0, cy = 0;                                                    \n"
+"  gdouble  cx = 0.5, cy = 0.5;                                                \n"
 "  gfloat  *in_pixel;                                                          \n"
 "  gint     n_components;                                                      \n"
 "  gint     aux_index, aux2_index;                                             \n"
@@ -241,6 +316,19 @@ static const char* op_c_source =
 "  const Babl *inout_format = gegl_operation_get_format (operation, \"input\");\n"
 "  const Babl *aux_format  = gegl_operation_get_format (operation, \"aux\");   \n"
 "                                                                              \n"
+"  if (o->center)                                                              \n"
+"    {                                                                         \n"
+"      cx = o->center_x;                                                       \n"
+"      cy = o->center_y;                                                       \n"
+"    }                                                                         \n"
+"                                                                              \n"
+"  cx = gegl_buffer_get_x (input) +                                            \n"
+"       gegl_coordinate_relative_to_pixel (cx,                                 \n"
+"                                          gegl_buffer_get_width (input));     \n"
+"  cy = gegl_buffer_get_y (input) +                                            \n"
+"       gegl_coordinate_relative_to_pixel (cy,                                 \n"
+"                                          gegl_buffer_get_height (input));    \n"
+"                                                                              \n"
 "  n_components = babl_format_get_n_components (inout_format);                 \n"
 "                                                                              \n"
 "  in_pixel = g_new (gfloat, n_components);                                    \n"
@@ -252,17 +340,35 @@ static const char* op_c_source =
 "                                   GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE);       \n"
 "                                                                              \n"
 "  if (aux)                                                                    \n"
-"    aux_index = gegl_buffer_iterator_add (iter, aux, result, level, aux_format,\n"
-"                                          GEGL_ACCESS_READ, o->abyss_policy); \n"
+"    {                                                                         \n"
+"      GeglRectangle rect = *result;                                           \n"
+"                                                                              \n"
+"      if (o->center)                                                          \n"
+"        {                                                                     \n"
+"          GeglRectangle *bounds = gegl_operation_source_get_bounding_box (operation, \"aux\");\n"
+"                                                                              \n"
+"          rect.x += bounds->x + bounds->width  / 2 - floor (cx);              \n"
+"          rect.y += bounds->y + bounds->height / 2 - floor (cy);              \n"
+"        }                                                                     \n"
+"                                                                              \n"
+"      aux_index = gegl_buffer_iterator_add (iter, aux, &rect, level, aux_format,\n"
+"                                            GEGL_ACCESS_READ, GEGL_ABYSS_NONE);\n"
+"    }                                                                         \n"
 "                                                                              \n"
 "  if (aux2)                                                                   \n"
-"    aux2_index = gegl_buffer_iterator_add (iter, aux2, result, level, aux_format,\n"
-"                                           GEGL_ACCESS_READ, o->abyss_policy);\n"
-"                                                                              \n"
-"  if (o->displace_mode == GEGL_DISPLACE_MODE_POLAR)                           \n"
 "    {                                                                         \n"
-"      cx = gegl_buffer_get_width (input) / 2.0;                               \n"
-"      cy = gegl_buffer_get_height (input) / 2.0;                              \n"
+"      GeglRectangle rect = *result;                                           \n"
+"                                                                              \n"
+"      if (o->center)                                                          \n"
+"        {                                                                     \n"
+"          GeglRectangle *bounds = gegl_operation_source_get_bounding_box (operation, \"aux2\");\n"
+"                                                                              \n"
+"          rect.x += bounds->x + bounds->width  / 2 - floor (cx);              \n"
+"          rect.y += bounds->y + bounds->height / 2 - floor (cy);              \n"
+"        }                                                                     \n"
+"                                                                              \n"
+"      aux2_index = gegl_buffer_iterator_add (iter, aux2, &rect, level, aux_format,\n"
+"                                             GEGL_ACCESS_READ, GEGL_ABYSS_NONE);\n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  while (gegl_buffer_iterator_next (iter))                                    \n"
@@ -275,7 +381,7 @@ static const char* op_c_source =
 "      for (y = iter->roi[0].y; y < iter->roi[0].y + iter->roi[0].height; y++) \n"
 "        for (x = iter->roi[0].x; x < iter->roi[0].x + iter->roi[0].width; x++)\n"
 "          {                                                                   \n"
-"            gdouble  src_x, src_y;                                            \n"
+"            gdouble src_x, src_y;                                             \n"
 "                                                                              \n"
 "            if (o->displace_mode == GEGL_DISPLACE_MODE_POLAR)                 \n"
 "              {                                                               \n"
