@@ -352,6 +352,8 @@ static const char* op_c_source =
 "    \"title\",       _(\"Edge Detection\"),                                   \n"
 "    \"categories\",  \"edge-detect\",                                         \n"
 "    \"license\",     \"GPL3+\",                                               \n"
+"    \"reference-hash\",  \"dd9be3825edb58d7b331ec8844a16b5c\",                \n"
+"    \"reference-hashB\", \"d18fdd59dd60ad454cdd202bcc9d3035\",                \n"
 "    \"description\", _(\"Several simple methods for detecting edges\"),       \n"
 "    NULL);                                                                    \n"
 "}                                                                             \n"
