@@ -105,7 +105,7 @@ static const char* kernel_source =
 "  int gid = get_global_id(0);                                     \n"
 "  float4 in_v  = in[gid];                                         \n"
 "  float4 out_v;                                                   \n"
-"  out_v.xyz =  ((in_v.xyz - black_level) * gain)                  \n"
+"  out_v.xyz =  ((in_v.xyz - black_level) * gain);                 \n"
 "  out_v.w   =  in_v.w;                                            \n"
 "  out[gid]  =  out_v;                                             \n"
 "}                                                                 \n";
@@ -180,6 +180,7 @@ gegl_op_class_init (GeglOpClass *klass)
     "name",        "gegl:exposure",
     "title",       _("Exposure"),
     "categories",  "color",
+    "reference-chain", "load path=images/standard-input.png exposure exposure=1.5",
     "description", _("Changes Exposure of an image, allows stepping HDR and photographs up/down in stops. "),
     "op-version",  "1:0",
     NULL);
