@@ -106,7 +106,7 @@ static const char* op_c_source =
 "\"  int gid = get_global_id(0);                                     \\n\"     \n"
 "\"  float4 in_v  = in[gid];                                         \\n\"     \n"
 "\"  float4 out_v;                                                   \\n\"     \n"
-"\"  out_v.xyz =  ((in_v.xyz - black_level) * gain)                  \\n\"     \n"
+"\"  out_v.xyz =  ((in_v.xyz - black_level) * gain);                 \\n\"     \n"
 "\"  out_v.w   =  in_v.w;                                            \\n\"     \n"
 "\"  out[gid]  =  out_v;                                             \\n\"     \n"
 "\"}                                                                 \\n\";    \n"
@@ -181,6 +181,7 @@ static const char* op_c_source =
 "    \"name\",        \"gegl:exposure\",                                       \n"
 "    \"title\",       _(\"Exposure\"),                                         \n"
 "    \"categories\",  \"color\",                                               \n"
+"    \"reference-chain\", \"load path=images/standard-input.png exposure exposure=1.5\",\n"
 "    \"description\", _(\"Changes Exposure of an image, allows stepping HDR and photographs up/down in stops. \"),\n"
 "    \"op-version\",  \"1:0\",                                                 \n"
 "    NULL);                                                                    \n"
