@@ -74,10 +74,14 @@ static const char* op_c_source =
 "property_double (cx, _(\"CX\"), -0.75)                                        \n"
 "    description (_(\"CX (No effect in Mandelbrot and Sierpinski)\"))          \n"
 "    value_range (-2.5, 2.5)                                                   \n"
+"    ui_meta     (\"visible\", \"! fractaltype {mandelbrot, sierpinski}\")     \n"
+"    ui_meta     (\"description\", \"''\")                                     \n"
 "                                                                              \n"
 "property_double (cy, _(\"CY\"), -0.2)                                         \n"
 "    description (_(\"CY (No effect in Mandelbrot and Sierpinski)\"))          \n"
 "    value_range (-2.5, 2.5)                                                   \n"
+"    ui_meta     (\"visible\", \"$cx.visible\")                                \n"
+"    ui_meta     (\"description\", \"''\")                                     \n"
 "                                                                              \n"
 "property_double (redstretch, _(\"Red stretching factor\"), 1.0)               \n"
 "    value_range (0.0, 1.0)                                                    \n"
@@ -429,6 +433,7 @@ static const char* op_c_source =
 "    \"name\",               \"gegl:fractal-explorer\",                        \n"
 "    \"title\",              _(\"Fractal Explorer\"),                          \n"
 "    \"categories\",         \"render:fractal\",                               \n"
+"    \"reference-hash\",     \"fd6c1f91d1a44d67e229754958627e7e\",             \n"
 "    \"position-dependent\", \"true\",                                         \n"
 "    \"license\",            \"GPL3+\",                                        \n"
 "    \"description\",        _(\"Rendering of multiple different fractal systems, with configurable coloring options.\"),\n"
