@@ -219,6 +219,118 @@ static const char* op_c_source =
 "  return TRUE;                                                                \n"
 "}                                                                             \n"
 "                                                                              \n"
+"#include \"opencl/gegl-cl.h\"                                                 \n"
+"#include \"gegl-buffer-cl-iterator.h\"                                        \n"
+"                                                                              \n"
+"#include \"opencl/gaussian-blur-selective.cl.h\"                              \n"
+"                                                                              \n"
+"static GeglClRunData *cl_data = NULL;                                         \n"
+"                                                                              \n"
+"static gboolean                                                               \n"
+"cl_gblur_selective (cl_mem                in,                                 \n"
+"                    cl_mem                delta,                              \n"
+"                    cl_mem                out,                                \n"
+"                    size_t                global_worksize,                    \n"
+"                    const GeglRectangle  *roi,                                \n"
+"                    gfloat                radius,                             \n"
+"                    gfloat                max_delta)                          \n"
+"{                                                                             \n"
+"  cl_int cl_err = 0;                                                          \n"
+"  size_t global_ws[2];                                                        \n"
+"                                                                              \n"
+"  if (!cl_data)                                                               \n"
+"    {                                                                         \n"
+"      const char *kernel_name[] = { \"cl_gblur_selective\", NULL };           \n"
+"      cl_data = gegl_cl_compile_and_build (gaussian_blur_selective_cl_source, \n"
+"                                           kernel_name);                      \n"
+"    }                                                                         \n"
+"                                                                              \n"
+"  if (!cl_data)                                                               \n"
+"    return TRUE;                                                              \n"
+"                                                                              \n"
+"  global_ws[0] = roi->width;                                                  \n"
+"  global_ws[1] = roi->height;                                                 \n"
+"                                                                              \n"
+"  gegl_cl_set_kernel_args (cl_data->kernel[0],                                \n"
+"                           sizeof(cl_mem),     &in,                           \n"
+"                           sizeof(cl_mem),     &delta,                        \n"
+"                           sizeof(cl_mem),     &out,                          \n"
+"                           sizeof(cl_float),   &radius,                       \n"
+"                           sizeof(cl_float),   &max_delta,                    \n"
+"                           NULL);                                             \n"
+"  CL_CHECK;                                                                   \n"
+"                                                                              \n"
+"  cl_err = gegl_clEnqueueNDRangeKernel (gegl_cl_get_command_queue (),         \n"
+"                                        cl_data->kernel[0], 2,                \n"
+"                                        NULL, global_ws, NULL,                \n"
+"                                        0, NULL, NULL);                       \n"
+"  CL_CHECK;                                                                   \n"
+"                                                                              \n"
+"  return FALSE;                                                               \n"
+"                                                                              \n"
+"error:                                                                        \n"
+"  return TRUE;                                                                \n"
+"}                                                                             \n"
+"                                                                              \n"
+"static gboolean                                                               \n"
+"cl_process (GeglOperation       *operation,                                   \n"
+"            GeglBuffer          *input,                                       \n"
+"            GeglBuffer          *aux,                                         \n"
+"            GeglBuffer          *output,                                      \n"
+"            const GeglRectangle *result)                                      \n"
+"{                                                                             \n"
+"  const Babl *in_format  = gegl_operation_get_format (operation, \"input\");  \n"
+"  const Babl *aux_format = gegl_operation_get_format (operation, \"aux\");    \n"
+"  const Babl *out_format = gegl_operation_get_format (operation, \"output\"); \n"
+"  gint err;                                                                   \n"
+"                                                                              \n"
+"  GeglProperties *o = GEGL_PROPERTIES (operation);                            \n"
+"                                                                              \n"
+"  GeglBufferClIterator *i = gegl_buffer_cl_iterator_new (output,              \n"
+"                                                         result,              \n"
+"                                                         out_format,          \n"
+"                                                         GEGL_CL_BUFFER_WRITE);\n"
+"                                                                              \n"
+"  gint radius  = o->blur_radius;                                              \n"
+"                                                                              \n"
+"  gint read = gegl_buffer_cl_iterator_add_2 (i,                               \n"
+"                                             input,                           \n"
+"                                             result,                          \n"
+"                                             in_format,                       \n"
+"                                             GEGL_CL_BUFFER_READ,             \n"
+"                                             radius, radius, radius, radius,  \n"
+"                                             GEGL_ABYSS_CLAMP);               \n"
+"                                                                              \n"
+"  gint delta = !aux ?                                                         \n"
+"               read :                                                         \n"
+"               gegl_buffer_cl_iterator_add_2 (i,                              \n"
+"                                              aux,                            \n"
+"                                              result,                         \n"
+"                                              aux_format,                     \n"
+"                                              GEGL_CL_BUFFER_READ,            \n"
+"                                              radius, radius, radius, radius, \n"
+"                                              GEGL_ABYSS_CLAMP);              \n"
+"                                                                              \n"
+"  while (gegl_buffer_cl_iterator_next (i, &err))                              \n"
+"    {                                                                         \n"
+"      if (err)                                                                \n"
+"        return FALSE;                                                         \n"
+"                                                                              \n"
+"      err = cl_gblur_selective(i->tex[read],                                  \n"
+"                               i->tex[delta],                                 \n"
+"                               i->tex[0],                                     \n"
+"                               i->size[0],                                    \n"
+"                               &i->roi[0],                                    \n"
+"                               o->blur_radius,                                \n"
+"                               o->max_delta);                                 \n"
+"                                                                              \n"
+"      if (err)                                                                \n"
+"        return FALSE;                                                         \n"
+"    }                                                                         \n"
+"                                                                              \n"
+"  return TRUE;                                                                \n"
+"}                                                                             \n"
+"                                                                              \n"
 "static gboolean                                                               \n"
 "process (GeglOperation       *operation,                                      \n"
 "         GeglBuffer          *input,                                          \n"
@@ -233,6 +345,10 @@ static const char* op_c_source =
 "                                                                              \n"
 "  compute = get_required_for_output (operation, \"input\", result);           \n"
 "                                                                              \n"
+"  if (gegl_operation_use_opencl (operation))                                  \n"
+"    if (cl_process (operation, input, aux, output, result))                   \n"
+"      return TRUE;                                                            \n"
+"                                                                              \n"
 "  success = gblur_selective (input, &compute,                                 \n"
 "                             aux,                                             \n"
 "                             output, result,                                  \n"
@@ -252,7 +368,7 @@ static const char* op_c_source =
 "  operation_class->prepare                   = prepare;                       \n"
 "  operation_class->get_required_for_output   = get_required_for_output;       \n"
 "  operation_class->get_invalidated_by_change = get_invalidated_by_change;     \n"
-"  operation_class->opencl_support            = FALSE;                         \n"
+"  operation_class->opencl_support            = TRUE;                          \n"
 "                                                                              \n"
 "  composer_class->process = process;                                          \n"
 "                                                                              \n"
