@@ -105,13 +105,13 @@ static const char* op_c_source =
 "    {                                                                         \n"
 "      gint nx,ny;                                                             \n"
 "                                                                              \n"
-"      nx = (x - o->x_offset) % o->x;                                          \n"
-"      ny = (y - o->y_offset) % o->y;                                          \n"
+"      nx = (x - o->x_offset) % (o->x>>level);                                 \n"
+"      ny = (y - o->y_offset) % (o->y>>level);                                 \n"
 "      /* handle case where % returns a negative number */                     \n"
 "      nx += nx < 0 ? o->x : 0;                                                \n"
 "      ny += ny < 0 ? o->y : 0;                                                \n"
 "                                                                              \n"
-"      if (nx < o->line_width || ny < o->line_height)                          \n"
+"      if (nx < (o->line_width>>level) || ny < (o->line_height>>level))        \n"
 "        {                                                                     \n"
 "          out_pixel[0]=line_color[0];                                         \n"
 "          out_pixel[1]=line_color[1];                                         \n"
@@ -158,6 +158,7 @@ static const char* op_c_source =
 "    \"title\",              _(\"Grid\"),                                      \n"
 "    \"position-dependent\", \"true\",                                         \n"
 "    \"categories\" ,        \"render\",                                       \n"
+"    \"reference-hash\",     \"cc9c401d7c8bcea7147499ecbeda9986\",             \n"
 "    \"description\",        _(\"Grid renderer\"),                             \n"
 "    \"position-dependent\", \"true\",                                         \n"
 "    NULL);                                                                    \n"
