@@ -500,9 +500,10 @@ static const char* op_c_source =
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "    \"name\",                  \"gegl:lens-distortion\",                      \n"
 "    \"title\",                 _(\"Lens Distortion\"),                        \n"
-"    \"categories\",            \"blur\",                                      \n"
+"    \"categories\",            \"distort\",                                   \n"
 "    \"position-dependent\",    \"true\",                                      \n"
 "    \"license\",               \"GPL3+\",                                     \n"
+"    \"reference-hash\",        \"991dbbc6def3811821265049f69c23b3\",          \n"
 "    \"reference-composition\", composition,                                   \n"
 "    \"description\", _(\"Corrects barrel or pincushion lens distortion.\"),   \n"
 "    NULL);                                                                    \n"
