@@ -23,6 +23,10 @@ property_enum (sampler_type, _("Resampling method"),
     GeglSamplerType, gegl_sampler_type,
     GEGL_SAMPLER_CUBIC)
 
+property_enum (abyss_policy, _("Abyss policy"),
+               GeglAbyssPolicy, gegl_abyss_policy,
+               GEGL_ABYSS_NONE)
+
 #else
 
 #define GEGL_OP_COMPOSER
@@ -49,9 +53,10 @@ get_required_for_output (GeglOperation       *operation,
                          const gchar         *input_pad,
                          const GeglRectangle *region)
 {
-  GeglRectangle result = *gegl_operation_source_get_bounding_box (operation, "input");
-
-  return result;
+  if (! strcmp (input_pad, "input"))
+    return *gegl_operation_source_get_bounding_box (operation, "input");
+  else
+    return *region;
 }
 
 static gboolean
@@ -83,51 +88,53 @@ process (GeglOperation       *operation,
       index_coords = gegl_buffer_iterator_add (it, aux, result, level, format_coords,
                                                GEGL_ACCESS_READ, GEGL_ABYSS_NONE);
       index_in = gegl_buffer_iterator_add (it, input, result, level, format_io,
-                                           GEGL_ACCESS_READ, GEGL_ABYSS_NONE);
+                                           GEGL_ACCESS_READ, o->abyss_policy);
 
       while (gegl_buffer_iterator_next (it))
         {
-          gint        i;
-          gint        n_pixels = it->length;
-          gint        x = it->roi->x; /* initial x                   */
-          gint        y = it->roi->y; /*           and y coordinates */
+          gint        w;
+          gint        h;
+          gfloat      x;
+          gfloat      y;
           gfloat     *in = it->data[index_in];
           gfloat     *out = it->data[index_out];
           gfloat     *coords = it->data[index_coords];
 
-          for (i=0; i<n_pixels; i++)
+          y = it->roi->y + 0.5; /* initial y coordinate */
+
+          for (h = it->roi->height; h; h--, y++)
             {
-              /* if the coordinate asked is an exact pixel, we fetch it directly, to avoid the blur of sampling */
-              if (coords[0] == x && coords[1] == y)
-                {
-                  out[0] = in[0];
-                  out[1] = in[1];
-                  out[2] = in[2];
-                  out[3] = in[3];
-                }
-              else
-                {
-                  gegl_sampler_get (sampler, coords[0], coords[1], NULL, out, GEGL_ABYSS_NONE);
-                }
+              x = it->roi->x + 0.5; /* initial x coordinate */
 
-              coords += 2;
-              in += 4;
-              out += 4;
-
-              /* update x and y coordinates */
-              x++;
-              if (x >= (it->roi->x + it->roi->width))
+              for (w = it->roi->width; w; w--, x++)
                 {
-                  x = it->roi->x;
-                  y++;
-                }
+                  /* if the coordinate asked is an exact pixel, we fetch it
+                   * directly, to avoid the blur of sampling */
+                  if (coords[0] == x && coords[1] == y)
+                    {
+                      out[0] = in[0];
+                      out[1] = in[1];
+                      out[2] = in[2];
+                      out[3] = in[3];
+                    }
+                  else
+                    {
+                      gegl_sampler_get (sampler, coords[0],
+                                                 coords[1],
+                                                 NULL, out,
+                                                 o->abyss_policy);
+                    }
 
+                  coords += 2;
+                  in += 4;
+                  out += 4;
+                }
             }
         }
     }
   else
     {
-      gegl_buffer_copy (input, result, GEGL_ABYSS_NONE,
+      gegl_buffer_copy (input, result, o->abyss_policy,
                         output, result);
     }
 
