@@ -24,6 +24,10 @@ static const char* op_c_source =
 "    GeglSamplerType, gegl_sampler_type,                                       \n"
 "    GEGL_SAMPLER_CUBIC)                                                       \n"
 "                                                                              \n"
+"property_enum (abyss_policy, _(\"Abyss policy\"),                             \n"
+"               GeglAbyssPolicy, gegl_abyss_policy,                            \n"
+"               GEGL_ABYSS_NONE)                                               \n"
+"                                                                              \n"
 "#else                                                                         \n"
 "                                                                              \n"
 "#define GEGL_OP_COMPOSER                                                      \n"
@@ -50,9 +54,10 @@ static const char* op_c_source =
 "                         const gchar         *input_pad,                      \n"
 "                         const GeglRectangle *region)                         \n"
 "{                                                                             \n"
-"  GeglRectangle result = *gegl_operation_source_get_bounding_box (operation, \"input\");\n"
-"                                                                              \n"
-"  return result;                                                              \n"
+"  if (! strcmp (input_pad, \"input\"))                                        \n"
+"    return *gegl_operation_source_get_bounding_box (operation, \"input\");    \n"
+"  else                                                                        \n"
+"    return *region;                                                           \n"
 "}                                                                             \n"
 "                                                                              \n"
 "static gboolean                                                               \n"
@@ -84,51 +89,53 @@ static const char* op_c_source =
 "      index_coords = gegl_buffer_iterator_add (it, aux, result, level, format_coords,\n"
 "                                               GEGL_ACCESS_READ, GEGL_ABYSS_NONE);\n"
 "      index_in = gegl_buffer_iterator_add (it, input, result, level, format_io,\n"
-"                                           GEGL_ACCESS_READ, GEGL_ABYSS_NONE);\n"
+"                                           GEGL_ACCESS_READ, o->abyss_policy);\n"
 "                                                                              \n"
 "      while (gegl_buffer_iterator_next (it))                                  \n"
 "        {                                                                     \n"
-"          gint        i;                                                      \n"
-"          gint        n_pixels = it->length;                                  \n"
-"          gint        x = it->roi->x; /* initial x                   */       \n"
-"          gint        y = it->roi->y; /*           and y coordinates */       \n"
+"          gint        w;                                                      \n"
+"          gint        h;                                                      \n"
+"          gfloat      x;                                                      \n"
+"          gfloat      y;                                                      \n"
 "          gfloat     *in = it->data[index_in];                                \n"
 "          gfloat     *out = it->data[index_out];                              \n"
 "          gfloat     *coords = it->data[index_coords];                        \n"
 "                                                                              \n"
-"          for (i=0; i<n_pixels; i++)                                          \n"
+"          y = it->roi->y + 0.5; /* initial y coordinate */                    \n"
+"                                                                              \n"
+"          for (h = it->roi->height; h; h--, y++)                              \n"
 "            {                                                                 \n"
-"              /* if the coordinate asked is an exact pixel, we fetch it directly, to avoid the blur of sampling */\n"
-"              if (coords[0] == x && coords[1] == y)                           \n"
-"                {                                                             \n"
-"                  out[0] = in[0];                                             \n"
-"                  out[1] = in[1];                                             \n"
-"                  out[2] = in[2];                                             \n"
-"                  out[3] = in[3];                                             \n"
-"                }                                                             \n"
-"              else                                                            \n"
-"                {                                                             \n"
-"                  gegl_sampler_get (sampler, coords[0], coords[1], NULL, out, GEGL_ABYSS_NONE);\n"
-"                }                                                             \n"
+"              x = it->roi->x + 0.5; /* initial x coordinate */                \n"
 "                                                                              \n"
-"              coords += 2;                                                    \n"
-"              in += 4;                                                        \n"
-"              out += 4;                                                       \n"
-"                                                                              \n"
-"              /* update x and y coordinates */                                \n"
-"              x++;                                                            \n"
-"              if (x >= (it->roi->x + it->roi->width))                         \n"
+"              for (w = it->roi->width; w; w--, x++)                           \n"
 "                {                                                             \n"
-"                  x = it->roi->x;                                             \n"
-"                  y++;                                                        \n"
-"                }                                                             \n"
+"                  /* if the coordinate asked is an exact pixel, we fetch it   \n"
+"                   * directly, to avoid the blur of sampling */               \n"
+"                  if (coords[0] == x && coords[1] == y)                       \n"
+"                    {                                                         \n"
+"                      out[0] = in[0];                                         \n"
+"                      out[1] = in[1];                                         \n"
+"                      out[2] = in[2];                                         \n"
+"                      out[3] = in[3];                                         \n"
+"                    }                                                         \n"
+"                  else                                                        \n"
+"                    {                                                         \n"
+"                      gegl_sampler_get (sampler, coords[0],                   \n"
+"                                                 coords[1],                   \n"
+"                                                 NULL, out,                   \n"
+"                                                 o->abyss_policy);            \n"
+"                    }                                                         \n"
 "                                                                              \n"
+"                  coords += 2;                                                \n"
+"                  in += 4;                                                    \n"
+"                  out += 4;                                                   \n"
+"                }                                                             \n"
 "            }                                                                 \n"
 "        }                                                                     \n"
 "    }                                                                         \n"
 "  else                                                                        \n"
 "    {                                                                         \n"
-"      gegl_buffer_copy (input, result, GEGL_ABYSS_NONE,                       \n"
+"      gegl_buffer_copy (input, result, o->abyss_policy,                       \n"
 "                        output, result);                                      \n"
 "    }                                                                         \n"
 "                                                                              \n"
