@@ -152,6 +152,128 @@ static const char* op_c_source =
 "  return phi;                                                                 \n"
 "}                                                                             \n"
 "                                                                              \n"
+"#include \"opencl/gegl-cl.h\"                                                 \n"
+"#include \"gegl-buffer-cl-iterator.h\"                                        \n"
+"                                                                              \n"
+"#include \"opencl/motion-blur-circular.cl.h\"                                 \n"
+"                                                                              \n"
+"static GeglClRunData *cl_data = NULL;                                         \n"
+"                                                                              \n"
+"static gboolean                                                               \n"
+"cl_motion_blur_circular (cl_mem               in,                             \n"
+"                         cl_mem               out,                            \n"
+"                         const GeglRectangle *src_rect,                       \n"
+"                         const GeglRectangle *dst_rect,                       \n"
+"                         const GeglRectangle *whole_region,                   \n"
+"                         gdouble              angle,                          \n"
+"                         gdouble              center_x,                       \n"
+"                         gdouble              center_y)                       \n"
+"{                                                                             \n"
+"  cl_int cl_err = 0;                                                          \n"
+"  size_t global_ws[2];                                                        \n"
+"  cl_float a, cx, cy;                                                         \n"
+"                                                                              \n"
+"  if (!cl_data)                                                               \n"
+"    {                                                                         \n"
+"      const char *kernel_name[] = { \"cl_motion_blur_circular\", NULL };      \n"
+"      cl_data = gegl_cl_compile_and_build (motion_blur_circular_cl_source,    \n"
+"                                           kernel_name);                      \n"
+"    }                                                                         \n"
+"                                                                              \n"
+"  if (!cl_data)                                                               \n"
+"    return TRUE;                                                              \n"
+"                                                                              \n"
+"  a  = (cl_float)angle;                                                       \n"
+"  cx = (cl_float)center_x;                                                    \n"
+"  cy = (cl_float)center_y;                                                    \n"
+"  cl_err = gegl_cl_set_kernel_args (cl_data->kernel[0],                       \n"
+"                                    sizeof(cl_mem),   &in,                    \n"
+"                                    sizeof(cl_mem),   &out,                   \n"
+"                                    sizeof(cl_int),   &src_rect->width,       \n"
+"                                    sizeof(cl_int),   &src_rect->height,      \n"
+"                                    sizeof(cl_int),   &src_rect->x,           \n"
+"                                    sizeof(cl_int),   &src_rect->y,           \n"
+"                                    sizeof(cl_int),   &dst_rect->x,           \n"
+"                                    sizeof(cl_int),   &dst_rect->y,           \n"
+"                                    sizeof(cl_int),   &whole_region->width,   \n"
+"                                    sizeof(cl_int),   &whole_region->height,  \n"
+"                                    sizeof(cl_int),   &whole_region->x,       \n"
+"                                    sizeof(cl_int),   &whole_region->y,       \n"
+"                                    sizeof(cl_float), &a,                     \n"
+"                                    sizeof(cl_float), &cx,                    \n"
+"                                    sizeof(cl_float), &cy,                    \n"
+"                                    NULL);                                    \n"
+"  CL_CHECK;                                                                   \n"
+"                                                                              \n"
+"  global_ws[0] = dst_rect->width;                                             \n"
+"  global_ws[1] = dst_rect->height;                                            \n"
+"  cl_err = gegl_clEnqueueNDRangeKernel (gegl_cl_get_command_queue (),         \n"
+"                                        cl_data->kernel[0], 2,                \n"
+"                                        NULL, global_ws, NULL,                \n"
+"                                        0, NULL, NULL);                       \n"
+"  CL_CHECK;                                                                   \n"
+"                                                                              \n"
+"  return FALSE;                                                               \n"
+"                                                                              \n"
+"error:                                                                        \n"
+"  return TRUE;                                                                \n"
+"}                                                                             \n"
+"                                                                              \n"
+"static gboolean                                                               \n"
+"cl_process (GeglOperation       *operation,                                   \n"
+"            GeglBuffer          *input,                                       \n"
+"            GeglBuffer          *output,                                      \n"
+"            const GeglRectangle *result,                                      \n"
+"            const GeglRectangle *whole_region,                                \n"
+"            gdouble              angle,                                       \n"
+"            gdouble              center_x,                                    \n"
+"            gdouble              center_y)                                    \n"
+"{                                                                             \n"
+"  GeglOperationAreaFilter *op_area = GEGL_OPERATION_AREA_FILTER (operation);  \n"
+"                                                                              \n"
+"  GeglBufferClIterator *i;                                                    \n"
+"  const Babl *in_format  = gegl_operation_get_format (operation, \"input\");  \n"
+"  const Babl *out_format = gegl_operation_get_format (operation, \"output\"); \n"
+"  gint        err;                                                            \n"
+"  gint        read;                                                           \n"
+"                                                                              \n"
+"  i = gegl_buffer_cl_iterator_new (output,                                    \n"
+"                                   result,                                    \n"
+"                                   out_format,                                \n"
+"                                   GEGL_CL_BUFFER_WRITE);                     \n"
+"                                                                              \n"
+"  read = gegl_buffer_cl_iterator_add_2 (i,                                    \n"
+"                                        input,                                \n"
+"                                        result,                               \n"
+"                                        in_format,                            \n"
+"                                        GEGL_CL_BUFFER_READ,                  \n"
+"                                        op_area->left,                        \n"
+"                                        op_area->right,                       \n"
+"                                        op_area->top,                         \n"
+"                                        op_area->bottom,                      \n"
+"                                        GEGL_ABYSS_NONE);                     \n"
+"                                                                              \n"
+"  while (gegl_buffer_cl_iterator_next (i, &err))                              \n"
+"    {                                                                         \n"
+"      if (err)                                                                \n"
+"        return FALSE;                                                         \n"
+"                                                                              \n"
+"      err = cl_motion_blur_circular (i->tex[read],                            \n"
+"                                     i->tex[0],                               \n"
+"                                     &i->roi[read],                           \n"
+"                                     &i->roi[0],                              \n"
+"                                     whole_region,                            \n"
+"                                     angle,                                   \n"
+"                                     center_x,                                \n"
+"                                     center_y);                               \n"
+"                                                                              \n"
+"      if (err)                                                                \n"
+"        return FALSE;                                                         \n"
+"    }                                                                         \n"
+"                                                                              \n"
+"  return TRUE;                                                                \n"
+"}                                                                             \n"
+"                                                                              \n"
 "static gboolean                                                               \n"
 "process (GeglOperation       *operation,                                      \n"
 "         GeglBuffer          *input,                                          \n"
@@ -175,6 +297,13 @@ static const char* op_c_source =
 "  center_y = gegl_coordinate_relative_to_pixel (                              \n"
 "                    o->center_y, whole_region->height);                       \n"
 "                                                                              \n"
+"  angle = o->angle * G_PI / 180.0;                                            \n"
+"  while (angle < 0.0)                                                         \n"
+"    angle += 2 * G_PI;                                                        \n"
+"                                                                              \n"
+"  if (gegl_operation_use_opencl (operation))                                  \n"
+"    if (cl_process (operation, input, output, roi, whole_region, angle, center_x, center_y))\n"
+"      return TRUE;                                                            \n"
 "                                                                              \n"
 "  src_rect = *roi;                                                            \n"
 "  src_rect.x -= op_area->left;                                                \n"
@@ -189,11 +318,6 @@ static const char* op_c_source =
 "  gegl_buffer_get (input, &src_rect, 1.0, babl_format (\"RaGaBaA float\"),    \n"
 "                   in_buf, GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);             \n"
 "                                                                              \n"
-"  angle = o->angle * G_PI / 180.0;                                            \n"
-"                                                                              \n"
-"  while (angle < 0.0)                                                         \n"
-"    angle += 2 * G_PI;                                                        \n"
-"                                                                              \n"
 "  for (y = roi->y; y < roi->height + roi->y; ++y)                             \n"
 "    {                                                                         \n"
 "      for (x = roi->x; x < roi->width + roi->x; ++x)                          \n"
@@ -291,6 +415,8 @@ static const char* op_c_source =
 "  filter_class    = GEGL_OPERATION_FILTER_CLASS (klass);                      \n"
 "                                                                              \n"
 "  operation_class->prepare = prepare;                                         \n"
+"  operation_class->opencl_support = TRUE;                                     \n"
+"                                                                              \n"
 "  filter_class->process    = process;                                         \n"
 "                                                                              \n"
 "  gegl_operation_class_set_keys (operation_class,                             \n"
