@@ -179,6 +179,84 @@ static const char* op_c_source =
 "  return TRUE;                                                                \n"
 "}                                                                             \n"
 "                                                                              \n"
+"#include \"opencl/gegl-cl.h\"                                                 \n"
+"#include \"opencl/noise-hsv.cl.h\"                                            \n"
+"                                                                              \n"
+"static GeglClRunData *cl_data = NULL;                                         \n"
+"                                                                              \n"
+"static gboolean                                                               \n"
+"cl_process (GeglOperation       *operation,                                   \n"
+"            cl_mem               in,                                          \n"
+"            cl_mem               out,                                         \n"
+"            size_t               global_worksize,                             \n"
+"            const GeglRectangle *roi,                                         \n"
+"            gint                 level)                                       \n"
+"{                                                                             \n"
+"  GeglProperties *o = GEGL_PROPERTIES (operation);                            \n"
+"  GeglRectangle *wr = gegl_operation_source_get_bounding_box (operation,      \n"
+"                                                              \"input\");     \n"
+"  cl_int      cl_err           = 0;                                           \n"
+"  cl_mem      cl_random_data   = NULL;                                        \n"
+"  cl_int      x_offset         = roi->x;                                      \n"
+"  cl_int      y_offset         = roi->y;                                      \n"
+"  cl_int      roi_width        = roi->width;                                  \n"
+"  cl_int      wr_width         = wr->width;                                   \n"
+"  cl_ushort4  rand;                                                           \n"
+"  cl_int      holdness;                                                       \n"
+"  cl_float    hue_distance;                                                   \n"
+"  cl_float    saturation_distance;                                            \n"
+"  cl_float    value_distance;                                                 \n"
+"                                                                              \n"
+"  gegl_cl_random_get_ushort4 (o->rand, &rand);                                \n"
+"                                                                              \n"
+"  if (!cl_data)                                                               \n"
+"    {                                                                         \n"
+"      const char *kernel_name[] = { \"cl_noise_hsv\", NULL };                 \n"
+"      cl_data = gegl_cl_compile_and_build (noise_hsv_cl_source, kernel_name); \n"
+"    }                                                                         \n"
+"                                                                              \n"
+"  if (!cl_data)                                                               \n"
+"    return TRUE;                                                              \n"
+"                                                                              \n"
+"  cl_random_data = gegl_cl_load_random_data (&cl_err);                        \n"
+"  CL_CHECK;                                                                   \n"
+"                                                                              \n"
+"  holdness = o->holdness;                                                     \n"
+"  hue_distance = o->hue_distance / 360.0;                                     \n"
+"  saturation_distance = o->saturation_distance;                               \n"
+"  value_distance = o->value_distance;                                         \n"
+"                                                                              \n"
+"  gegl_cl_set_kernel_args (cl_data->kernel[0],                                \n"
+"                           sizeof(cl_mem),     &in,                           \n"
+"                           sizeof(cl_mem),     &out,                          \n"
+"                           sizeof(cl_mem),     &cl_random_data,               \n"
+"                           sizeof(cl_ushort4), &rand,                         \n"
+"                           sizeof(cl_int),     &x_offset,                     \n"
+"                           sizeof(cl_int),     &y_offset,                     \n"
+"                           sizeof(cl_int),     &roi_width,                    \n"
+"                           sizeof(cl_int),     &wr_width,                     \n"
+"                           sizeof(cl_int),     &holdness,                     \n"
+"                           sizeof(cl_float),   &hue_distance,                 \n"
+"                           sizeof(cl_float),   &saturation_distance,          \n"
+"                           sizeof(cl_float),   &value_distance,               \n"
+"                           NULL);                                             \n"
+"                                                                              \n"
+"  CL_CHECK;                                                                   \n"
+"  cl_err = gegl_clEnqueueNDRangeKernel (gegl_cl_get_command_queue (),         \n"
+"                                        cl_data->kernel[0], 1,                \n"
+"                                        NULL, &global_worksize, NULL,         \n"
+"                                        0, NULL, NULL);                       \n"
+"  CL_CHECK;                                                                   \n"
+"                                                                              \n"
+"  cl_err = gegl_clFinish (gegl_cl_get_command_queue ());                      \n"
+"  CL_CHECK;                                                                   \n"
+"                                                                              \n"
+"  return  FALSE;                                                              \n"
+"                                                                              \n"
+"error:                                                                        \n"
+"  return TRUE;                                                                \n"
+"}                                                                             \n"
+"                                                                              \n"
 "static void                                                                   \n"
 "gegl_op_class_init (GeglOpClass *klass)                                       \n"
 "{                                                                             \n"
@@ -189,7 +267,9 @@ static const char* op_c_source =
 "  point_filter_class = GEGL_OPERATION_POINT_FILTER_CLASS (klass);             \n"
 "                                                                              \n"
 "  operation_class->prepare = prepare;                                         \n"
+"  operation_class->opencl_support = TRUE;                                     \n"
 "  point_filter_class->process = process;                                      \n"
+"  point_filter_class->cl_process = cl_process;                                \n"
 "                                                                              \n"
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "    \"name\",       \"gegl:noise-hsv\",                                       \n"
