@@ -71,16 +71,16 @@ static const char* op_c_source =
 " * K+M, ACM Trans Math Software 3 (1977) 257-260.                             \n"
 "*/                                                                            \n"
 "static gfloat                                                                 \n"
-"noise_gauss (GeglRandom *rand, int *i, int xx, int yy)                        \n"
+"noise_gauss (GeglRandom *rand, gint xx, gint yy, gint *n)                     \n"
 "{                                                                             \n"
 "  gfloat u, v, x;                                                             \n"
 "                                                                              \n"
 "  do                                                                          \n"
 "  {                                                                           \n"
-"    v = gegl_random_float (rand, xx, yy, 0, (*i)++);                          \n"
+"    v = gegl_random_float (rand, xx, yy, 0, (*n)++);                          \n"
 "                                                                              \n"
 "    do                                                                        \n"
-"      u = gegl_random_float (rand, xx, yy, 0, (*i)++);                        \n"
+"      u = gegl_random_float (rand, xx, yy, 0, (*n)++);                        \n"
 "    while (u == 0);                                                           \n"
 "                                                                              \n"
 "    /* Const 1.715... = sqrt(8/e) */                                          \n"
@@ -92,9 +92,9 @@ static const char* op_c_source =
 "}                                                                             \n"
 "                                                                              \n"
 "static gfloat                                                                 \n"
-"noise_linear (GeglRandom *rand, int *i, int xx, int yy)                       \n"
+"noise_linear (GeglRandom *rand, gint xx, gint yy, gint *n)                    \n"
 "{                                                                             \n"
-"  return gegl_random_float (rand, xx, yy, 0, (*i)++) * 2 - 1.0;               \n"
+"  return gegl_random_float (rand, xx, yy, 0, (*n)++) * 2 - 1.0;               \n"
 "}                                                                             \n"
 "                                                                              \n"
 "static void                                                                   \n"
@@ -124,14 +124,13 @@ static const char* op_c_source =
 "  GeglProperties *o  = GEGL_PROPERTIES (operation);                           \n"
 "                                                                              \n"
 "  gdouble  noise_coeff = 0.0;                                                 \n"
-"  int      rint = 0;                                                          \n"
 "  gint     b, i;                                                              \n"
 "  gint     x, y;                                                              \n"
 "  gdouble  noise[4];                                                          \n"
 "  gfloat   tmp;                                                               \n"
 "  gfloat   * GEGL_ALIGNED in_pixel;                                           \n"
 "  gfloat   * GEGL_ALIGNED out_pixel;                                          \n"
-"  gfloat   (*noise_fun) (GeglRandom *rand, int *i, int xx, int yy) = noise_gauss;\n"
+"  gfloat   (*noise_fun) (GeglRandom *rand, gint xx, gint yy, gint *n) = noise_gauss;\n"
 "                                                                              \n"
 "  in_pixel   = in_buf;                                                        \n"
 "  out_pixel  = out_buf;                                                       \n"
@@ -149,10 +148,12 @@ static const char* op_c_source =
 "                                                                              \n"
 "  for (i=0; i<n_pixels; i++)                                                  \n"
 "  {                                                                           \n"
+"    gint n = 0;                                                               \n"
+"                                                                              \n"
 "    for (b = 0; b < 4; b++)                                                   \n"
 "    {                                                                         \n"
 "      if (b == 0 || o->independent || b == 3 )                                \n"
-"         noise_coeff = noise[b] * noise_fun (o->rand, &rint, x, y) * 0.5;     \n"
+"         noise_coeff = noise[b] * noise_fun (o->rand, x, y, &n) * 0.5;        \n"
 "                                                                              \n"
 "      if (noise[b] > 0.0)                                                     \n"
 "      {                                                                       \n"
@@ -200,9 +201,10 @@ static const char* op_c_source =
 "  point_filter_class->process = process;                                      \n"
 "                                                                              \n"
 "  gegl_operation_class_set_keys (operation_class,                             \n"
-"    \"name\",        \"gegl:noise-rgb\",                                      \n"
-"    \"title\",       _(\"Add RGB Noise\"),                                    \n"
-"    \"categories\",  \"noise\",                                               \n"
+"    \"name\",           \"gegl:noise-rgb\",                                   \n"
+"    \"title\",          _(\"Add RGB Noise\"),                                 \n"
+"    \"categories\",     \"noise\",                                            \n"
+"    \"reference-hash\", \"2783edddbc10bb2e9cbf8372a2d913ef\",                 \n"
 "    \"description\", _(\"Distort colors by random amounts\"),                 \n"
 "    NULL);                                                                    \n"
 "}                                                                             \n"
