@@ -54,15 +54,18 @@ static const char* op_c_source =
 "  value_range (0, G_MAXINT)                                                   \n"
 "  ui_meta     (\"unit\", \"pixel-coordinate\")                                \n"
 "  ui_meta     (\"axis\", \"x\")                                               \n"
+"  ui_meta     (\"sensitive\", \"$middle.sensitive & ! middle\")               \n"
 "                                                                              \n"
 "property_int  (pole_y, _(\"Y\"), 0)                                           \n"
 "  description (_(\"Origin point for the polar coordinates\"))                 \n"
 "  value_range (0, G_MAXINT)                                                   \n"
 "  ui_meta     (\"unit\", \"pixel-coordinate\")                                \n"
 "  ui_meta     (\"axis\", \"y\")                                               \n"
+"  ui_meta     (\"sensitive\", \"$pole-x.sensitive\")                          \n"
 "                                                                              \n"
 "property_boolean (middle, _(\"Choose middle\"), TRUE)                         \n"
-"  description(_(\"Let origin point to be the middle one\"))                   \n"
+"  description (_(\"Let origin point to be the middle one\"))                  \n"
+"  ui_meta     (\"sensitive\", \"polar\")                                      \n"
 "                                                                              \n"
 "#else                                                                         \n"
 "                                                                              \n"
@@ -92,6 +95,8 @@ static const char* op_c_source =
 "static gboolean                                                               \n"
 "calc_undistorted_coords (gdouble        wx,                                   \n"
 "                         gdouble        wy,                                   \n"
+"                         gdouble        cen_x,                                \n"
+"                         gdouble        cen_y,                                \n"
 "                         gdouble       *x,                                    \n"
 "                         gdouble       *y,                                    \n"
 "                         GeglProperties    *o,                                \n"
@@ -105,7 +110,7 @@ static const char* op_c_source =
 "  gdouble  m;                                                                 \n"
 "  gdouble  xmax, ymax, rmax;                                                  \n"
 "  gdouble  x_calc, y_calc;                                                    \n"
-"  gdouble  xi, yi, cen_x, cen_y;                                              \n"
+"  gdouble  xi, yi;                                                            \n"
 "  gdouble  circle, angl, t, angle;                                            \n"
 "  gint     x1, x2, y1, y2;                                                    \n"
 "                                                                              \n"
@@ -125,9 +130,6 @@ static const char* op_c_source =
 "  circle = o->depth;                                                          \n"
 "  angle  = o->angle;                                                          \n"
 "  angl   = (gdouble) angle / 180.0 * G_PI;                                    \n"
-"  cen_x  = o->pole_x;                                                         \n"
-"  cen_y  = o->pole_y;                                                         \n"
-"                                                                              \n"
 "                                                                              \n"
 "  if (o->polar)                                                               \n"
 "    {                                                                         \n"
@@ -335,6 +337,7 @@ static const char* op_c_source =
 "  gint      i, offset = 0;                                                    \n"
 "  gboolean  inside;                                                           \n"
 "  gdouble   px, py;                                                           \n"
+"  gdouble   cen_x, cen_y;                                                     \n"
 "                                                                              \n"
 "  GeglMatrix2  scale;        /* a matrix indicating scaling factors around the\n"
 "                                current center pixel.                         \n"
@@ -347,8 +350,13 @@ static const char* op_c_source =
 "                                                                              \n"
 "  if (o->middle)                                                              \n"
 "    {                                                                         \n"
-"      o->pole_x = boundary.width / 2;                                         \n"
-"      o->pole_y = boundary.height / 2;                                        \n"
+"      cen_x = boundary.width / 2;                                             \n"
+"      cen_y = boundary.height / 2;                                            \n"
+"    }                                                                         \n"
+"  else                                                                        \n"
+"    {                                                                         \n"
+"      cen_x = o->pole_x;                                                      \n"
+"      cen_y = o->pole_y;                                                      \n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  for (y = result->y; y < result->y + result->height; y++)                    \n"
@@ -357,7 +365,8 @@ static const char* op_c_source =
 "#define gegl_unmap(u,v,ud,vd) {                                         \\    \n"
 "          gdouble rx = 0.0, ry = 0.0;                                   \\    \n"
 "          inside = calc_undistorted_coords ((gdouble)x, (gdouble)y,     \\    \n"
-"                                            &rx, &ry, o, boundary);     \\    \n"
+"                                            cen_x, cen_y, &rx, &ry,     \\    \n"
+"                                            o, boundary);               \\    \n"
 "          ud = rx;                                                      \\    \n"
 "          vd = ry;                                                      \\    \n"
 "        }                                                                     \n"
@@ -427,6 +436,7 @@ static const char* op_c_source =
 "    \"title\",              _(\"Polar Coordinates\"),                         \n"
 "    \"categories\",         \"transform:map\",                                \n"
 "    \"position-dependent\", \"true\",                                         \n"
+"    \"reference-hash\",     \"0134a2706e736d2594f4d6da8d4fd3cb\",             \n"
 "    \"license\",            \"GPL3+\",                                        \n"
 "    \"description\", _(\"Convert image to or from polar coordinates\"),       \n"
 "    NULL);                                                                    \n"
