@@ -32,7 +32,6 @@ static const char* op_c_source =
 "#define GEGL_OP_POINT_FILTER                                                  \n"
 "#define GEGL_OP_NAME     posterize                                            \n"
 "#define GEGL_OP_C_SOURCE posterize.c                                          \n"
-"#define GEGLV4                                                                \n"
 "                                                                              \n"
 "#include \"gegl-op.h\"                                                        \n"
 "                                                                              \n"
@@ -132,6 +131,7 @@ static const char* op_c_source =
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "    \"name\",        \"gegl:posterize\",                                      \n"
 "    \"title\",       _(\"Posterize\"),                                        \n"
+"    \"reference-hash\", \"6c325366cad73837346ea052aea4d7dc\",                 \n"
 "    \"categories\" , \"color\",                                               \n"
 "    \"description\",                                                          \n"
 "       _(\"Reduces the number of levels in each color component of the image.\"),\n"
