@@ -41,8 +41,10 @@ typedef struct {
 } AutostretchData;
 
 static void
-buffer_get_auto_stretch_data (GeglBuffer      *buffer,
-                             AutostretchData *data)
+buffer_get_auto_stretch_data (GeglOperation       *operation,
+                              GeglBuffer          *buffer,
+                              const GeglRectangle *result,
+                              AutostretchData     *data)
 {
   gfloat smin =  G_MAXFLOAT;
   gfloat smax = -G_MAXFLOAT;
@@ -50,8 +52,11 @@ buffer_get_auto_stretch_data (GeglBuffer      *buffer,
   gfloat vmax = -G_MAXFLOAT;
 
   GeglBufferIterator *gi;
+  gint                done_pixels = 0;
 
-  gi = gegl_buffer_iterator_new (buffer, NULL, 0, babl_format ("HSVA float"),
+  gegl_operation_progress (operation, 0.0, "");
+
+  gi = gegl_buffer_iterator_new (buffer, result, 0, babl_format ("HSVA float"),
                                  GEGL_ACCESS_READ, GEGL_ABYSS_NONE);
 
   while (gegl_buffer_iterator_next (gi))
@@ -71,6 +76,13 @@ buffer_get_auto_stretch_data (GeglBuffer      *buffer,
 
           buf += 4;
         }
+
+      done_pixels += gi->length;
+
+      gegl_operation_progress (operation,
+                               (gdouble) 0.5 * done_pixels /
+                               (gdouble) (result->width * result->height),
+                               "");
     }
 
   if (data)
@@ -80,6 +92,8 @@ buffer_get_auto_stretch_data (GeglBuffer      *buffer,
       data->vlo   = vmin;
       data->vdiff = vmax - vmin;
     }
+
+  gegl_operation_progress (operation, 0.5, "");
 }
 
 static void
@@ -140,10 +154,13 @@ process (GeglOperation       *operation,
 {
   AutostretchData     data;
   GeglBufferIterator *gi;
+  gint                done_pixels = 0;
 
-  buffer_get_auto_stretch_data (input, &data);
+  buffer_get_auto_stretch_data (operation, input, result, &data);
   clean_autostretch_data (&data);
 
+  gegl_operation_progress (operation, 0.5, "");
+
   gi = gegl_buffer_iterator_new (input, result, 0, babl_format ("HSVA float"),
                                  GEGL_ACCESS_READ, GEGL_ABYSS_NONE);
 
@@ -166,8 +183,18 @@ process (GeglOperation       *operation,
           in  += 4;
           out += 4;
         }
+
+      done_pixels += gi->length;
+
+      gegl_operation_progress (operation,
+                               0.5 +
+                               (gdouble) 0.5 * done_pixels /
+                               (gdouble) (result->width * result->height),
+                               "");
     }
 
+  gegl_operation_progress (operation, 1.0, "");
+
   return TRUE;
 }
 
