@@ -42,8 +42,10 @@ static const char* op_c_source =
 "} AutostretchData;                                                            \n"
 "                                                                              \n"
 "static void                                                                   \n"
-"buffer_get_auto_stretch_data (GeglBuffer      *buffer,                        \n"
-"                             AutostretchData *data)                           \n"
+"buffer_get_auto_stretch_data (GeglOperation       *operation,                 \n"
+"                              GeglBuffer          *buffer,                    \n"
+"                              const GeglRectangle *result,                    \n"
+"                              AutostretchData     *data)                      \n"
 "{                                                                             \n"
 "  gfloat smin =  G_MAXFLOAT;                                                  \n"
 "  gfloat smax = -G_MAXFLOAT;                                                  \n"
@@ -51,8 +53,11 @@ static const char* op_c_source =
 "  gfloat vmax = -G_MAXFLOAT;                                                  \n"
 "                                                                              \n"
 "  GeglBufferIterator *gi;                                                     \n"
+"  gint                done_pixels = 0;                                        \n"
 "                                                                              \n"
-"  gi = gegl_buffer_iterator_new (buffer, NULL, 0, babl_format (\"HSVA float\"),\n"
+"  gegl_operation_progress (operation, 0.0, \"\");                             \n"
+"                                                                              \n"
+"  gi = gegl_buffer_iterator_new (buffer, result, 0, babl_format (\"HSVA float\"),\n"
 "                                 GEGL_ACCESS_READ, GEGL_ABYSS_NONE);          \n"
 "                                                                              \n"
 "  while (gegl_buffer_iterator_next (gi))                                      \n"
@@ -72,6 +77,13 @@ static const char* op_c_source =
 "                                                                              \n"
 "          buf += 4;                                                           \n"
 "        }                                                                     \n"
+"                                                                              \n"
+"      done_pixels += gi->length;                                              \n"
+"                                                                              \n"
+"      gegl_operation_progress (operation,                                     \n"
+"                               (gdouble) 0.5 * done_pixels /                  \n"
+"                               (gdouble) (result->width * result->height),    \n"
+"                               \"\");                                         \n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  if (data)                                                                   \n"
@@ -81,6 +93,8 @@ static const char* op_c_source =
 "      data->vlo   = vmin;                                                     \n"
 "      data->vdiff = vmax - vmin;                                              \n"
 "    }                                                                         \n"
+"                                                                              \n"
+"  gegl_operation_progress (operation, 0.5, \"\");                             \n"
 "}                                                                             \n"
 "                                                                              \n"
 "static void                                                                   \n"
@@ -141,10 +155,13 @@ static const char* op_c_source =
 "{                                                                             \n"
 "  AutostretchData     data;                                                   \n"
 "  GeglBufferIterator *gi;                                                     \n"
+"  gint                done_pixels = 0;                                        \n"
 "                                                                              \n"
-"  buffer_get_auto_stretch_data (input, &data);                                \n"
+"  buffer_get_auto_stretch_data (operation, input, result, &data);             \n"
 "  clean_autostretch_data (&data);                                             \n"
 "                                                                              \n"
+"  gegl_operation_progress (operation, 0.5, \"\");                             \n"
+"                                                                              \n"
 "  gi = gegl_buffer_iterator_new (input, result, 0, babl_format (\"HSVA float\"),\n"
 "                                 GEGL_ACCESS_READ, GEGL_ABYSS_NONE);          \n"
 "                                                                              \n"
@@ -167,8 +184,18 @@ static const char* op_c_source =
 "          in  += 4;                                                           \n"
 "          out += 4;                                                           \n"
 "        }                                                                     \n"
+"                                                                              \n"
+"      done_pixels += gi->length;                                              \n"
+"                                                                              \n"
+"      gegl_operation_progress (operation,                                     \n"
+"                               0.5 +                                          \n"
+"                               (gdouble) 0.5 * done_pixels /                  \n"
+"                               (gdouble) (result->width * result->height),    \n"
+"                               \"\");                                         \n"
 "    }                                                                         \n"
 "                                                                              \n"
+"  gegl_operation_progress (operation, 1.0, \"\");                             \n"
+"                                                                              \n"
 "  return TRUE;                                                                \n"
 "}                                                                             \n"
 "                                                                              \n"
