@@ -91,6 +91,8 @@ static const char* op_c_source =
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "    \"name\"       , \"gegl:svg-luminancetoalpha\",                           \n"
 "    \"categories\" , \"compositors:svgfilter\",                               \n"
+"    \"title\"      , _(\"SVG Luminance to Alpha\"),                           \n"
+"    \"reference-hash\", \"6763517c5421d736b855ffa2ebd845c9\",                 \n"
 "    \"description\",                                                          \n"
 "       _(\"SVG color matrix operation svg_luminancetoalpha\"),                \n"
 "        NULL);                                                                \n"
