@@ -382,7 +382,8 @@ static const char* op_c_source =
 "    \"name\",               \"gegl:vignette\",                                \n"
 "    \"title\",              _(\"Vignette\"),                                  \n"
 "    \"position-dependent\", \"true\",                                         \n"
-"    \"categories\",         \"render:photo\",                                 \n"
+"    \"categories\",         \"render:light\",                                 \n"
+"    \"reference-hash\",     \"2057d35e0e44881c3319f0474e847d97\",             \n"
 "    \"description\", _(\"Applies a vignette to an image. Simulates the luminance \"\n"
 "                     \"fall off at the edge of exposed film, and some other \"\n"
 "                     \"fuzzier border effects that can naturally occur with \"\n"
