@@ -89,9 +89,9 @@ static const char* op_c_source =
 "                                                                              \n"
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "    \"name\",        \"gegl:cache\",                                          \n"
-"    \"title\",       _(\"Explicit cache of results at this point of graph.\"),\n"
+"    \"title\",       _(\"Cache\"),                                            \n"
 "    \"categories\",  \"programming\",                                         \n"
-"    \"description\", _(\"An explicit caching node\"),                         \n"
+"    \"description\", _(\"An explicit caching node, caches results and should provide faster recomputation if what is cached by it is expensive but isn't changing.\"),\n"
 "    NULL);                                                                    \n"
 "}                                                                             \n"
 "                                                                              \n"
