@@ -109,7 +109,7 @@ static const char* op_c_source =
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "       \"name\",          \"gegl:clone\",                                     \n"
 "       \"title\",         _(\"Clone\"),                                       \n"
-"       \"description\",   _(\"Clone a buffer\"),                              \n"
+"       \"description\",   _(\"Clone a buffer, this is the same as gegl:nop but can get special treatment to get more human readable references in serializations/UI.\"),\n"
 "       \"categories\",    \"core\",                                           \n"
 "       NULL);                                                                 \n"
 "}                                                                             \n"
