@@ -416,10 +416,11 @@ static const char* op_c_source =
 "                                                                              \n"
 "  gegl_operation_set_format (operation, \"output\", babl_format (\"R'G'B' u8\"));\n"
 "                                                                              \n"
-"  if (!p->loadedfilename ||                                                   \n"
+"  if (o->path &&                                                              \n"
+"      (!p->loadedfilename ||                                                  \n"
 "      strcmp (p->loadedfilename, o->path) ||                                  \n"
 "       p->prevframe > o->frame  /* a bit heavy handed, but improves consistency */\n"
-"      )                                                                       \n"
+"      ))                                                                      \n"
 "    {                                                                         \n"
 "      gint i;                                                                 \n"
 "      gchar *dereferenced_path;                                               \n"
@@ -427,6 +428,8 @@ static const char* op_c_source =
 "                                                                              \n"
 "      ff_cleanup (o);                                                         \n"
 "      dereferenced_path = realpath (o->path, NULL);                           \n"
+"      if (!dereferenced_path)                                                 \n"
+"        return;                                                               \n"
 "      err = avformat_open_input(&p->video_fcontext, dereferenced_path, NULL, 0);\n"
 "      free (dereferenced_path);                                               \n"
 "      if (err < 0)                                                            \n"
@@ -555,7 +558,7 @@ static const char* op_c_source =
 "          strstr (p->video_fcontext->filename, \".MP4\"))  /* XXX: too hacky, isn't there an avformat thing to use?,\n"
 " or perhaps we can measure this when decoding the first frame.                \n"
 " */                                                                           \n"
-"        p->codec_delay = 3;                                                   \n"
+"        p->codec_delay = 1;                                                   \n"
 "      else                                                                    \n"
 "        p->codec_delay = 0;                                                   \n"
 "    }                                                                         \n"
@@ -681,7 +684,7 @@ static const char* op_c_source =
 "  Priv       *p = (Priv*)o->user_data;                                        \n"
 "                                                                              \n"
 "  {                                                                           \n"
-"    if (p->video_fcontext && !decode_frame (operation, o->frame))             \n"
+"    if (o->path && p->video_fcontext && !decode_frame (operation, o->frame))  \n"
 "      {                                                                       \n"
 "        long sample_start = 0;                                                \n"
 "                                                                              \n"
