@@ -131,6 +131,8 @@ static const char* op_c_source =
 "  long      audio_read_pos;                                                   \n"
 "                                                                              \n"
 "  int       next_apts;                                                        \n"
+"                                                                              \n"
+"  int       file_inited;                                                      \n"
 "} Priv;                                                                       \n"
 "                                                                              \n"
 "static void                                                                   \n"
@@ -971,7 +973,6 @@ static const char* op_c_source =
 "{                                                                             \n"
 "  GeglProperties *o = GEGL_PROPERTIES (operation);                            \n"
 "  Priv *p = (Priv*)o->user_data;                                              \n"
-"  static gint     inited = 0;                                                 \n"
 "                                                                              \n"
 "  g_assert (input);                                                           \n"
 "                                                                              \n"
@@ -983,10 +984,10 @@ static const char* op_c_source =
 "  p->height = result->height;                                                 \n"
 "  p->input = input;                                                           \n"
 "                                                                              \n"
-"  if (!inited)                                                                \n"
+"  if (!p->file_inited)                                                        \n"
 "    {                                                                         \n"
 "      tfile (o);                                                              \n"
-"      inited = 1;                                                             \n"
+"      p->file_inited = 1;                                                     \n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  write_video_frame (o, p->oc, p->video_st);                                  \n"
@@ -1092,6 +1093,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "    \"name\"        , \"gegl:ff-save\",                                       \n"
+"    \"title\"       , _(\"FFmpeg Frame Saver\"),                              \n"
 "    \"categories\"  , \"output:video\",                                       \n"
 "    \"description\" , _(\"FFmpeg video output sink\"),                        \n"
 "    NULL);                                                                    \n"
