@@ -385,7 +385,7 @@ static const char* op_c_source =
 "          guchar *data;                                                       \n"
 "                                                                              \n"
 "          g_mutex_lock (&mutex);                                              \n"
-"          data = gegl_buffer_linear_open (output, result, NULL, babl_format (\"B'aG'aR'aA u8\"));\n"
+"          data = gegl_buffer_linear_open (output, result, NULL, babl_format (\"cairo-ARGB32\"));\n"
 "          surface = cairo_image_surface_create_for_data (data,                \n"
 "                                                         CAIRO_FORMAT_ARGB32, \n"
 "                                                         result->width,       \n"
