@@ -162,8 +162,11 @@ prepare (GeglOperation *operation)
       stream = gegl_gio_open_input_stream (o->uri, o->path, &p->file, &error);
       if (stream == NULL)
         {
-          g_warning ("%s", error->message);
-          g_error_free (error);
+          if (error)
+            {
+              g_warning ("%s", error->message);
+              g_error_free (error);
+            }
           cleanup (operation);
           return;
         }
