@@ -219,7 +219,7 @@ static const char* op_c_source =
 "  cairo_translate (cr, -result->x, -result->y);                               \n"
 "  text_layout_text (self, cr, 0, NULL);                                       \n"
 "                                                                              \n"
-"  gegl_buffer_set (output, result, 0, babl_format (\"B'aG'aR'aA u8\"), data,  \n"
+"  gegl_buffer_set (output, result, 0, babl_format (\"cairo-ARGB32\"), data,   \n"
 "                   GEGL_AUTO_ROWSTRIDE);                                      \n"
 "                                                                              \n"
 "  cairo_destroy (cr);                                                         \n"
