@@ -48,7 +48,9 @@ static const char* op_c_source =
 "#include \"gegl-op.h\"                                                        \n"
 "                                                                              \n"
 "#include \"v4lutils/v4lutils.h\"                                              \n"
-"#define GEGL_OP_C_SOURCE v4lutils/v4lutils.c                                  \n"
+"#include \"v4lutils/v4lutils.c\"                                              \n"
+"                                                                              \n"
+"#define GEGL_OP_C_SOURCE v4l.c                                                \n"
 "                                                                              \n"
 "typedef struct                                                                \n"
 "{                                                                             \n"
