@@ -206,8 +206,11 @@ static const char* op_c_source =
 "      p->stream = gegl_gio_open_input_stream (o->uri, o->path, &p->file, &error);\n"
 "      if (p->stream == NULL)                                                  \n"
 "        {                                                                     \n"
-"          g_warning (\"%s\", error->message);                                 \n"
-"          g_error_free (error);                                               \n"
+"          if (error)                                                          \n"
+"          {                                                                   \n"
+"            g_warning (\"%s\", error->message);                               \n"
+"            g_error_free (error);                                             \n"
+"          }                                                                   \n"
 "          cleanup (operation);                                                \n"
 "          return;                                                             \n"
 "        }                                                                     \n"
