@@ -992,9 +992,9 @@ static const char* op_c_source =
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "  \"name\"        , \"gegl:gluas\",                                           \n"
 "  \"categories\"  , \"script:misc\",                                          \n"
+"  \"title\"       , _(\"gluas\"),                                             \n"
 "  \"description\" ,                                                           \n"
-"        _(\"A general purpose filter/composer implementation proxy for the\"  \n"
-"          \" lua programming language.\"),                                    \n"
+"        _(\"Pixel level filter/composer scripting prototyping with lua. See http://pippin.gimp.org/image-processing/ for further details.\"),\n"
 "        NULL);                                                                \n"
 "}                                                                             \n"
 "                                                                              \n"
