@@ -383,7 +383,7 @@ static const char* op_c_source =
 "  gfloat          x0;                                                         \n"
 "  gfloat          y0;                                                         \n"
 "  gfloat          radius    = scale * o->radius;                              \n"
-"  gfloat          thickness = (1.0 - o->balance) / 2.0;                       \n"
+"  gfloat          thickness = (1.0 + o->balance) / 2.0;                       \n"
 "  gfloat          angle     = o->rotation / 360.0;                            \n"
 "  gboolean        clockwise = o->direction == GEGL_SPIRAL_DIRECTION_CLOCKWISE;\n"
 "  gfloat          color1[4];                                                  \n"
